from .... pyaz_utils import call_az

def list(gateway_name, resource_group):
    '''
    List trusted root certificates.
    '''
    return call_az("az network application-gateway root-cert list", locals())


def show(gateway_name, name, resource_group):
    '''
    Get the details of a trusted root certificate.
    '''
    return call_az("az network application-gateway root-cert show", locals())


def delete(gateway_name, name, resource_group, no_wait=None):
    '''
    Delete a trusted root certificate.
    '''
    return call_az("az network application-gateway root-cert delete", locals())


def create(gateway_name, name, resource_group, cert_file=None, keyvault_secret=None, no_wait=None):
    '''
    Upload a trusted root certificate.
    '''
    return call_az("az network application-gateway root-cert create", locals())


def update(gateway_name, name, resource_group, add=None, cert_file=None, force_string=None, keyvault_secret=None, no_wait=None, remove=None, set=None):
    '''
    Update a trusted root certificate.
    '''
    return call_az("az network application-gateway root-cert update", locals())




from ... pyaz_utils import call_az

def list(account_name, filter=None, profile_name=None, search=None):
    '''
    List the customers that are billed to a billing account. The operation is supported only for billing accounts with agreement type Microsoft Partner Agreement.
    '''
    return call_az("az billing customer list", locals())


def show(account_name, name, expand=None):
    '''
    Get a customer by its ID. The operation is supported only for billing accounts with agreement type Microsoft Partner Agreement.
    '''
    return call_az("az billing customer show", locals())




from .... pyaz_utils import call_az

def start(resource, storage_account, storage_path, no_wait=None, resource_group=None, resource_type=None):
    '''
    Troubleshoot issues with VPN connections or gateway connectivity.
    '''
    return call_az("az network watcher troubleshooting start", locals())


def show(resource, resource_group=None, resource_type=None):
    '''
    Get the results of the last troubleshooting operation.
    '''
    return call_az("az network watcher troubleshooting show", locals())




from .... pyaz_utils import call_az

def list(lb_name, resource_group):
    '''
    List probes.
    '''
    return call_az("az network lb probe list", locals())


def show(lb_name, name, resource_group):
    '''
    Get the details of a probe.
    '''
    return call_az("az network lb probe show", locals())


def delete(lb_name, name, resource_group):
    '''
    Delete a probe.
    '''
    return call_az("az network lb probe delete", locals())


def create(lb_name, name, port, protocol, resource_group, interval=None, path=None, threshold=None):
    '''
    Create a probe.
    '''
    return call_az("az network lb probe create", locals())


def update(lb_name, name, resource_group, add=None, force_string=None, interval=None, path=None, port=None, protocol=None, remove=None, set=None, threshold=None):
    '''
    Update a probe.
    '''
    return call_az("az network lb probe update", locals())




from ... pyaz_utils import call_az
from . import credential, owner


def create(id):
    '''
    Create a service principal.
    '''
    return call_az("az ad sp create", locals())


def delete(id):
    '''
    Delete a service principal and its role assignments.
    '''
    return call_az("az ad sp delete", locals())


def list(all=None, display_name=None, filter=None, show_mine=None, spn=None):
    '''
    List service principals.
    '''
    return call_az("az ad sp list", locals())


def show(id):
    '''
    Get the details of a service principal.
    '''
    return call_az("az ad sp show", locals())


def update(id, add=None, force_string=None, remove=None, set=None):
    '''
    Update a service principal
    '''
    return call_az("az ad sp update", locals())


def create_for_rbac(cert=None, create_cert=None, keyvault=None, name=None, role=None, scopes=None, sdk_auth=None, skip_assignment=None, years=None):
    '''
    Create a service principal and configure its access to Azure resources.
    '''
    return call_az("az ad sp create-for-rbac", locals())




from ... pyaz_utils import call_az

def list():
    '''
    List Azure Advisor configuration for the entire subscription.
    '''
    return call_az("az advisor configuration list", locals())


def show(resource_group=None):
    '''
    Show Azure Advisor configuration for the given subscription or resource group.
    '''
    return call_az("az advisor configuration show", locals())


def update(add=None, configuration_name=None, exclude=None, force_string=None, include=None, low_cpu_threshold=None, remove=None, resource_group=None, set=None):
    '''
    Update Azure Advisor configuration.
    '''
    return call_az("az advisor configuration update", locals())




from ..... pyaz_utils import call_az

def list(alias, name, namespace_name, resource_group):
    '''
    Shows the keys and connection strings of Authorizationrule for the EventHubs Namespace
    '''
    return call_az("az eventhubs georecovery-alias authorization-rule keys list", locals())




from ... pyaz_utils import call_az

def show(name, resource_group=None):
    '''
    Show the container registry's identity details
    '''
    return call_az("az acr identity show", locals())


def assign(identities, name, resource_group=None):
    '''
    Assign a managed identity to a container registry
    '''
    return call_az("az acr identity assign", locals())


def remove(identities, name, resource_group=None):
    '''
    Remove a managed identity from a container registry
    '''
    return call_az("az acr identity remove", locals())




from .... pyaz_utils import call_az

def assign(name, resource_group):
    '''
    Assign an identity of a Cognitive Services account.
    '''
    return call_az("az cognitiveservices account identity assign", locals())


def remove(name, resource_group):
    '''
    Remove the identity from a Cognitive Services account.
    '''
    return call_az("az cognitiveservices account identity remove", locals())


def show(name, resource_group):
    '''
    Show the identity of a Cognitive Services account.
    '''
    return call_az("az cognitiveservices account identity show", locals())




from ... pyaz_utils import call_az

def show(name, resource_group):
    '''
    Show the identities for a Azure Cosmos DB database account.
    '''
    return call_az("az cosmosdb identity show", locals())


def assign(name, resource_group, identities=None):
    '''
    Assign SystemAssigned identity for a Azure Cosmos DB database account.
    '''
    return call_az("az cosmosdb identity assign", locals())


def remove(name, resource_group, identities=None):
    '''
    Remove SystemAssigned identity for a Azure Cosmos DB database account.
    '''
    return call_az("az cosmosdb identity remove", locals())




from ... pyaz_utils import call_az
from . import rule


def delete(name, resource_group):
    '''
    Delete a network security group.
    '''
    return call_az("az network nsg delete", locals())


def show(name, resource_group, expand=None):
    '''
    Get information about a network security group.
    '''
    return call_az("az network nsg show", locals())


def list(resource_group=None):
    '''
    List network security groups.
    '''
    return call_az("az network nsg list", locals())


def create(name, resource_group, location=None, tags=None):
    '''
    Create a network security group.
    '''
    return call_az("az network nsg create", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None):
    '''
    Update a network security group.
    '''
    return call_az("az network nsg update", locals())




from ..... pyaz_utils import call_az

def add(action_group, name, resource_group, reset=None, strict=None, webhook_properties=None):
    '''
    Add action groups to this activity log alert. It can also be used to overwrite existing webhook properties of particular action groups.
    '''
    return call_az("az monitor activity-log alert action-group add", locals())


def remove(action_group, name, resource_group):
    '''
    Remove action groups from this activity log alert
    '''
    return call_az("az monitor activity-log alert action-group remove", locals())




from ... pyaz_utils import call_az

def set(key, auth_mode=None, connection_string=None, content_type=None, endpoint=None, label=None, name=None, tags=None, value=None, yes=None):
    '''
    Set a key-value.
    '''
    return call_az("az appconfig kv set", locals())


def delete(key, auth_mode=None, connection_string=None, endpoint=None, label=None, name=None, yes=None):
    '''
    Delete key-values.
    '''
    return call_az("az appconfig kv delete", locals())


def show(key, auth_mode=None, connection_string=None, datetime=None, endpoint=None, label=None, name=None):
    '''
    Show all attributes of a key-value.
    '''
    return call_az("az appconfig kv show", locals())


def list(all=None, auth_mode=None, connection_string=None, datetime=None, endpoint=None, fields=None, key=None, label=None, name=None, resolve_keyvault=None, top=None):
    '''
    List key-values.
    '''
    return call_az("az appconfig kv list", locals())


def lock(key, auth_mode=None, connection_string=None, endpoint=None, label=None, name=None, yes=None):
    '''
    Lock a key-value to prohibit write operations.
    '''
    return call_az("az appconfig kv lock", locals())


def unlock(key, auth_mode=None, connection_string=None, endpoint=None, label=None, name=None, yes=None):
    '''
    Unlock a key-value to gain write operations.
    '''
    return call_az("az appconfig kv unlock", locals())


def restore(datetime, auth_mode=None, connection_string=None, endpoint=None, key=None, label=None, name=None, yes=None):
    '''
    Restore key-values.
    '''
    return call_az("az appconfig kv restore", locals())


def import_(source, appservice_account=None, auth_mode=None, connection_string=None, content_type=None, depth=None, endpoint=None, format=None, label=None, name=None, path=None, prefix=None, preserve_labels=None, profile=None, separator=None, skip_features=None, src_auth_mode=None, src_connection_string=None, src_endpoint=None, src_key=None, src_label=None, src_name=None, yes=None):
    '''
    Import configurations into your App Configuration from another place.
    '''
    return call_az("az appconfig kv import", locals())


def export(destination, appservice_account=None, auth_mode=None, connection_string=None, dest_auth_mode=None, dest_connection_string=None, dest_endpoint=None, dest_label=None, dest_name=None, endpoint=None, format=None, key=None, label=None, name=None, naming_convention=None, path=None, prefix=None, preserve_labels=None, profile=None, resolve_keyvault=None, separator=None, skip_features=None, skip_keyvault=None, yes=None):
    '''
    Export configurations to another place from your App Configuration.
    '''
    return call_az("az appconfig kv export", locals())


def set_keyvault(key, secret_identifier, auth_mode=None, connection_string=None, endpoint=None, label=None, name=None, tags=None, yes=None):
    '''
    Set a keyvault reference.
    '''
    return call_az("az appconfig kv set-keyvault", locals())




from ... pyaz_utils import call_az
from . import credential, owner, permission


def create(display_name, app_roles=None, available_to_other_tenants=None, credential_description=None, end_date=None, homepage=None, identifier_uris=None, key_type=None, key_usage=None, key_value=None, native_app=None, oauth2_allow_implicit_flow=None, optional_claims=None, password=None, reply_urls=None, required_resource_accesses=None, start_date=None):
    '''
    Create a web application, web API or native application
    '''
    return call_az("az ad app create", locals())


def delete(id):
    '''
    Delete an application.
    '''
    return call_az("az ad app delete", locals())


def list(all=None, app_id=None, display_name=None, filter=None, identifier_uri=None, show_mine=None):
    '''
    List applications.
    '''
    return call_az("az ad app list", locals())


def show(id):
    '''
    Get the details of an application.
    '''
    return call_az("az ad app show", locals())


def update(id, add=None, app_roles=None, available_to_other_tenants=None, credential_description=None, display_name=None, end_date=None, force_string=None, homepage=None, identifier_uris=None, key_type=None, key_usage=None, key_value=None, oauth2_allow_implicit_flow=None, optional_claims=None, password=None, remove=None, reply_urls=None, required_resource_accesses=None, set=None, start_date=None):
    '''
    Update an application.
    '''
    return call_az("az ad app update", locals())




from .... pyaz_utils import call_az

def show(account_name, resource_group=None):
    '''
    Show the properties of file service in storage account.
    '''
    return call_az("az storage account file-service-properties show", locals())


def update(account_name, add=None, auth_methods=None, channel_encryption=None, delete_retention_days=None, enable_delete_retention=None, enable_smb_multichannel=None, force_string=None, kerb_ticket_encryption=None, remove=None, resource_group=None, set=None, versions=None):
    '''
    Update the properties of file service in storage account.
    '''
    return call_az("az storage account file-service-properties update", locals())




from ... pyaz_utils import call_az
from . import peering


def create(hosted_subnet, name, resource_group, location=None, public_ip_address=None, tags=None):
    '''
    Create a route server.
    '''
    return call_az("az network routeserver create", locals())


def update(name, resource_group, add=None, allow_b2b_traffic=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Update a route server.
    '''
    return call_az("az network routeserver update", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    Delete a route server under a resource group.
    '''
    return call_az("az network routeserver delete", locals())


def show(name, resource_group):
    '''
    Show a route server.
    '''
    return call_az("az network routeserver show", locals())


def list(resource_group=None):
    '''
    List all route servers under a subscription or a resource group.
    '''
    return call_az("az network routeserver list", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the route server is met.
    '''
    return call_az("az network routeserver wait", locals())




from .... pyaz_utils import call_az

def add(account_name, name, preset, resource_group, audio_analysis_mode=None, audio_language=None, insights_to_extract=None, on_error=None, relative_priority=None, resolution=None, video_analysis_mode=None):
    '''
    Add an output to an existing transform.
    '''
    return call_az("az ams transform output add", locals())


def remove(account_name, name, output_index, resource_group):
    '''
    Remove an output from an existing transform.
    '''
    return call_az("az ams transform output remove", locals())




from ... pyaz_utils import call_az

def list(cluster_name, resource_group):
    '''
    List managed applications of a given managed cluster.
    '''
    return call_az("az sf managed-application list", locals())


def delete(cluster_name, name, resource_group):
    '''
    Delete a managed application.
    '''
    return call_az("az sf managed-application delete", locals())


def show(cluster_name, name, resource_group):
    '''
    Show the properties of a managed application on an Azure Service Fabric managed cluster.
    '''
    return call_az("az sf managed-application show", locals())


def create(cluster_name, name, resource_group, type_name, version, package_url=None, parameters=None, tags=None):
    '''
    Create a new managed application on an Azure Service Fabric managed cluster.
    '''
    return call_az("az sf managed-application create", locals())


def update(cluster_name, name, resource_group, failure_action=None, force_restart=None, hc_retry_timeout=None, hc_stable_duration=None, hc_wait_duration=None, instance_close_delay_duration=None, max_percent_unhealthy_deployed_applications=None, max_percent_unhealthy_partitions=None, max_percent_unhealthy_replicas=None, max_percent_unhealthy_services=None, parameters=None, recreate_application=None, service_type_health_policy_map=None, tags=None, ud_timeout=None, upgrade_mode=None, upgrade_replica_set_check_timeout=None, upgrade_timeout=None, version=None, warning_as_error=None):
    '''
    Update a Azure Service Fabric managed application.
    '''
    return call_az("az sf managed-application update", locals())




from .... pyaz_utils import call_az

def list(name, resource_group, slot=None):
    '''
    Get a web app's connection strings.
    '''
    return call_az("az webapp config connection-string list", locals())


def set(connection_string_type, name, resource_group, settings=None, slot=None, slot_settings=None):
    '''
    Update a web app's connection strings.
    '''
    return call_az("az webapp config connection-string set", locals())


def delete(name, resource_group, setting_names, slot=None):
    '''
    Delete a web app's connection strings.
    '''
    return call_az("az webapp config connection-string delete", locals())




from .. pyaz_utils import call_az
from . import lock, management_group


def list(all=None, refresh=None):
    '''
    Get a list of subscriptions for the logged in account. By default, only 'Enabled' subscriptions from the current cloud is shown.
    '''
    return call_az("az account list", locals())


def set(subscription):
    '''
    Set a subscription to be the current active subscription.
    '''
    return call_az("az account set", locals())


def show(sdk_auth=None, subscription=None):
    '''
    Get the details of a subscription.
    '''
    return call_az("az account show", locals())


def clear():
    '''
    Clear all subscriptions from the CLI's local cache.
    '''
    return call_az("az account clear", locals())


def list_locations():
    '''
    List supported regions for the current subscription.
    '''
    return call_az("az account list-locations", locals())


def get_access_token(resource=None, resource_type=None, scope=None, subscription=None, tenant=None):
    '''
    Get a token for utilities to access Azure.
    '''
    return call_az("az account get-access-token", locals())




from ..... pyaz_utils import call_az

def show(resource_group, zone_name, name=None, record_type=None):
    '''
    Get the details of an SOA record.
    '''
    return call_az("az network dns record-set soa show", locals())


def update(resource_group, zone_name, email=None, expire_time=None, host=None, if_none_match=None, minimum_ttl=None, refresh_time=None, retry_time=None, serial_number=None):
    '''
    Update properties of an SOA record.
    '''
    return call_az("az network dns record-set soa update", locals())




from ... pyaz_utils import call_az

def list(cluster_name, resource_group):
    '''
    List the hosts of the specified HDInsight cluster.
    '''
    return call_az("az hdinsight host list", locals())


def restart(cluster_name, host_names, resource_group, yes=None):
    '''
    Restart the specific hosts of the specified HDInsight cluster.
    '''
    return call_az("az hdinsight host restart", locals())




from .. pyaz_utils import call_az
from . import application_gateway, asg, bastion, cross_region_lb, ddos_protection, dns, express_route, lb, local_gateway, nic, nsg, private_endpoint, private_endpoint_connection, private_link_resource, private_link_service, profile, public_ip, route_filter, route_table, routeserver, security_partner_provider, service_endpoint, virtual_appliance, vnet, vnet_gateway, vpn_connection, vrouter, watcher


def list_usages(location):
    '''
    List the number of network resources in a region that are used against a subscription quota.
    '''
    return call_az("az network list-usages", locals())


def list_service_tags(location):
    '''
    List all service tags which are below to different resources
    '''
    return call_az("az network list-service-tags", locals())


def list_service_aliases(location, resource_group=None):
    '''
    List available service aliases in the region which can be used for Service Endpoint Policies.
    '''
    return call_az("az network list-service-aliases", locals())




from ... pyaz_utils import call_az

def list():
    '''
    Get operations from all providers.
    '''
    return call_az("az provider operation list", locals())


def show(namespace):
    '''
    Get an individual provider's operations.
    '''
    return call_az("az provider operation show", locals())




from ... pyaz_utils import call_az

def delete(name, resource_group, no_wait=None):
    '''
    Delete a virtual cluster.
    '''
    return call_az("az sql virtual-cluster delete", locals())


def show(name, resource_group):
    '''
    Get the details for a virtual cluster.
    '''
    return call_az("az sql virtual-cluster show", locals())


def list(resource_group=None):
    '''
    List available virtual clusters.
    '''
    return call_az("az sql virtual-cluster list", locals())




from .... pyaz_utils import call_az

def accept(offer=None, plan=None, publisher=None, urn=None):
    '''
    Accept Azure Marketplace image terms so that the image can be used to create VMs.
    '''
    return call_az("az vm image terms accept", locals())


def cancel(offer=None, plan=None, publisher=None, urn=None):
    '''
    Cancel Azure Marketplace image terms.
    '''
    return call_az("az vm image terms cancel", locals())


def show(offer=None, plan=None, publisher=None, urn=None):
    '''
    Get the details of Azure Marketplace image terms.
    '''
    return call_az("az vm image terms show", locals())




from .... pyaz_utils import call_az

def show(name, resource_group, slot=None):
    '''
    Show Access Restriction settings for webapp.
    '''
    return call_az("az webapp config access-restriction show", locals())


def add(name, priority, resource_group, action=None, description=None, http_headers=None, ignore_missing_endpoint=None, ip_address=None, rule_name=None, scm_site=None, service_tag=None, slot=None, subnet=None, vnet_name=None, vnet_resource_group=None):
    '''
    Adds an Access Restriction to the webapp.
    '''
    return call_az("az webapp config access-restriction add", locals())


def remove(name, resource_group, action=None, ip_address=None, rule_name=None, scm_site=None, service_tag=None, slot=None, subnet=None, vnet_name=None):
    '''
    Removes an Access Restriction from the webapp.
    '''
    return call_az("az webapp config access-restriction remove", locals())


def set(name, resource_group, use_same_restrictions_for_scm_site, slot=None):
    '''
    Sets if SCM site is using the same restrictions as the main site.
    '''
    return call_az("az webapp config access-restriction set", locals())




from ... pyaz_utils import call_az

def create(account_endpoint=None, account_key=None, account_name=None, do_not_run_after=None, do_not_run_until=None, id=None, job_manager_task_command_line=None, job_manager_task_id=None, job_manager_task_resource_files=None, job_max_task_retry_count=None, job_max_wall_clock_time=None, json_file=None, max_parallel_tasks=None, metadata=None, on_all_tasks_complete=None, pool_id=None, priority=None, recurrence_interval=None, required_slots=None, start_window=None, uses_task_dependencies=None):
    '''
    Add a Batch job schedule to an account.
    '''
    return call_az("az batch job-schedule create", locals())


def delete(job_schedule_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, yes=None):
    return call_az("az batch job-schedule delete", locals())


def show(job_schedule_id, account_endpoint=None, account_key=None, account_name=None, expand=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, select=None):
    return call_az("az batch job-schedule show", locals())


def set(job_schedule_id, account_endpoint=None, account_key=None, account_name=None, do_not_run_after=None, do_not_run_until=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, job_manager_task_application_package_references=None, job_manager_task_command_line=None, job_manager_task_environment_settings=None, job_manager_task_id=None, job_manager_task_resource_files=None, job_metadata=None, json_file=None, max_parallel_tasks=None, metadata=None, on_all_tasks_complete=None, pool_id=None, priority=None, recurrence_interval=None, required_slots=None, start_window=None, uses_task_dependencies=None):
    '''
    Update the properties of a job schedule.
    '''
    return call_az("az batch job-schedule set", locals())


def reset(job_schedule_id, account_endpoint=None, account_key=None, account_name=None, do_not_run_after=None, do_not_run_until=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, job_manager_task_application_package_references=None, job_manager_task_command_line=None, job_manager_task_environment_settings=None, job_manager_task_id=None, job_manager_task_resource_files=None, job_metadata=None, json_file=None, max_parallel_tasks=None, metadata=None, on_all_tasks_complete=None, pool_id=None, priority=None, recurrence_interval=None, required_slots=None, start_window=None, uses_task_dependencies=None):
    '''
    Reset the properties of a job schedule.  An updated job specification only applies to new jobs.
    '''
    return call_az("az batch job-schedule reset", locals())


def disable(job_schedule_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None):
    return call_az("az batch job-schedule disable", locals())


def enable(job_schedule_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None):
    return call_az("az batch job-schedule enable", locals())


def stop(job_schedule_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None):
    return call_az("az batch job-schedule stop", locals())


def list(account_endpoint=None, account_key=None, account_name=None, expand=None, filter=None, select=None):
    return call_az("az batch job-schedule list", locals())




from ... pyaz_utils import call_az

def list(account_name, invoice_name):
    '''
    List the transactions for an invoice. Transactions include purchases, refunds and Azure usage charges.
    '''
    return call_az("az billing transaction list", locals())




from ... pyaz_utils import call_az
from . import peering


def create(name, resource_group, hosted_gateway=None, hosted_subnet=None, location=None, tags=None):
    '''
    Create a virtual router.
    '''
    return call_az("az network vrouter create", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Update a virtual router.
    '''
    return call_az("az network vrouter update", locals())


def delete(name, resource_group):
    '''
    Delete a virtual router under a resource group.
    '''
    return call_az("az network vrouter delete", locals())


def show(name, resource_group):
    '''
    Show a virtual router.
    '''
    return call_az("az network vrouter show", locals())


def list(resource_group=None):
    '''
    List all virtual routers under a subscription or a resource group.
    '''
    return call_az("az network vrouter list", locals())




from ... pyaz_utils import call_az

def assign(name, resource_group, identities=None, role=None, scope=None, slot=None):
    '''
    assign managed identity to the web app
    '''
    return call_az("az webapp identity assign", locals())


def show(name, resource_group, slot=None):
    '''
    display web app's managed identity
    '''
    return call_az("az webapp identity show", locals())


def remove(name, resource_group, identities=None, slot=None):
    '''
    Disable web app's managed identity
    '''
    return call_az("az webapp identity remove", locals())




from .... pyaz_utils import call_az

def show(namespace_name, resource_group):
    '''
    Get the private link resources that need to be created for a eventhubs namespace.
    '''
    return call_az("az eventhubs namespace private-link-resource show", locals())




from .... pyaz_utils import call_az

def add(hostname, name, resource_group, slot=None):
    '''
    Bind a hostname to a function app.
    '''
    return call_az("az functionapp config hostname add", locals())


def list(resource_group, webapp_name, slot=None):
    '''
    List all hostname bindings for a function app.
    '''
    return call_az("az functionapp config hostname list", locals())


def delete(hostname, name, resource_group, slot=None):
    '''
    Unbind a hostname from a function app.
    '''
    return call_az("az functionapp config hostname delete", locals())


def get_external_ip(name, resource_group):
    '''
    Get the external-facing IP address for a function app.
    '''
    return call_az("az functionapp config hostname get-external-ip", locals())




from ... pyaz_utils import call_az

def link(function_resource_id, name, resource_group, force=None):
    '''
    Link an Azure Function to a static webapp. Also known as "Bring your own Functions." Only one Azure Functions app is available to a single static web app. Static webapp SKU must be "Standard"
    '''
    return call_az("az staticwebapp functions link", locals())


def unlink(name, resource_group):
    '''
    Unlink an Azure Function from a static webapp
    '''
    return call_az("az staticwebapp functions unlink", locals())


def show(name, resource_group):
    '''
    Show details on the Azure Function linked to a static webapp
    '''
    return call_az("az staticwebapp functions show", locals())




from .... pyaz_utils import call_az

def list(name, resource_group, slot=None):
    '''
    Get a web app's Azure storage account configurations. (Linux Web Apps and Windows Containers Web Apps Only)
    '''
    return call_az("az webapp config storage-account list", locals())


def add(access_key, account_name, custom_id, name, resource_group, share_name, storage_type, mount_path=None, slot=None, slot_setting=None):
    '''
    Add an Azure storage account configuration to a web app. (Linux Web Apps and Windows Containers Web Apps Only)
    '''
    return call_az("az webapp config storage-account add", locals())


def update(custom_id, name, resource_group, access_key=None, account_name=None, mount_path=None, share_name=None, slot=None, slot_setting=None, storage_type=None):
    '''
    Update an existing Azure storage account configuration on a web app. (Linux Web Apps and Windows Containers Web Apps Only)
    '''
    return call_az("az webapp config storage-account update", locals())


def delete(custom_id, name, resource_group, slot=None):
    '''
    Delete a web app's Azure storage account configuration. (Linux Web Apps and Windows Containers Web Apps Only)
    '''
    return call_az("az webapp config storage-account delete", locals())




from ... pyaz_utils import call_az
from . import log_replay, ltr_backup, ltr_policy, short_term_retention_policy


def list_deleted(managed_instance, resource_group):
    '''
    List restorable deleted managed databases.
    '''
    return call_az("az sql midb list-deleted", locals())


def create(managed_instance, name, resource_group, collation=None, no_wait=None):
    '''
    Create a managed database.
    '''
    return call_az("az sql midb create", locals())


def restore(dest_name, managed_instance, name, resource_group, time, deleted_time=None, dest_mi=None, dest_resource_group=None, no_wait=None):
    '''
    Restore a managed database.
    '''
    return call_az("az sql midb restore", locals())


def show(managed_instance, name, resource_group):
    '''
    Get the details for a managed database.
    '''
    return call_az("az sql midb show", locals())


def list(managed_instance, resource_group):
    '''
    List managed databases on a managed instance.
    '''
    return call_az("az sql midb list", locals())


def delete(managed_instance, name, resource_group, no_wait=None, yes=None):
    '''
    Delete a managed database.
    '''
    return call_az("az sql midb delete", locals())




from ... pyaz_utils import call_az
from . import customizer, output


def create(name, resource_group, build_timeout=None, checksum=None, identity=None, image_source=None, image_template=None, location=None, managed_image_destinations=None, no_wait=None, os_disk_size=None, scripts=None, shared_image_destinations=None, subnet=None, tags=None, vm_size=None, vnet=None):
    '''
    Create an image builder template.
    '''
    return call_az("az image builder create", locals())


def list(resource_group=None):
    '''
    List image builder templates.
    '''
    return call_az("az image builder list", locals())


def show(name, resource_group):
    '''
    Show an image builder template.
    '''
    return call_az("az image builder show", locals())


def delete(name, resource_group):
    '''
    Delete image builder template.
    '''
    return call_az("az image builder delete", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None):
    '''
    Update an image builder template.
    '''
    return call_az("az image builder update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the template is met.
    '''
    return call_az("az image builder wait", locals())


def run(name, resource_group, no_wait=None):
    '''
    Build an image builder template.
    '''
    return call_az("az image builder run", locals())


def show_runs(name, resource_group, output_name=None):
    '''
    Show an image builder template's run outputs.
    '''
    return call_az("az image builder show-runs", locals())


def cancel(name, resource_group):
    '''
    Cancel the long running image build based on the image template.
    '''
    return call_az("az image builder cancel", locals())




from .... pyaz_utils import call_az

def create(hub_name, name, event_hub_name=None, resource_group=None):
    '''
    Create an event hub consumer group.
    '''
    return call_az("az iot hub consumer-group create", locals())


def list(hub_name, event_hub_name=None, resource_group=None):
    '''
    List event hub consumer groups.
    '''
    return call_az("az iot hub consumer-group list", locals())


def show(hub_name, name, event_hub_name=None, resource_group=None):
    '''
    Get the details for an event hub consumer group.
    '''
    return call_az("az iot hub consumer-group show", locals())


def delete(hub_name, name, event_hub_name=None, resource_group=None):
    '''
    Delete an event hub consumer group.
    '''
    return call_az("az iot hub consumer-group delete", locals())




from .... pyaz_utils import call_az

def upload(node_id, pool_id, account_endpoint=None, account_key=None, account_name=None, container_url=None, end_time=None, json_file=None, resource_id=None, start_time=None):
    return call_az("az batch node service-logs upload", locals())




from ... pyaz_utils import call_az
from . import firewall_rule, key, managed_identity


def show(name, resource_group):
    '''
    Get a Synapse workspace.
    '''
    return call_az("az synapse workspace show", locals())


def list(resource_group=None):
    '''
    List all Synapse workspaces.
    '''
    return call_az("az synapse workspace list", locals())


def create(file_system, name, resource_group, sql_admin_login_password, sql_admin_login_user, storage_account, account_name=None, allowed_tenant_ids=None, collaboration_branch=None, enable_managed_vnet=None, host_name=None, key_identifier=None, key_name=None, location=None, no_wait=None, prevent_exfiltration=None, project_name=None, repository_name=None, repository_type=None, root_folder=None, tags=None, tenant_id=None):
    '''
    Create a Synapse workspace.
    '''
    return call_az("az synapse workspace create", locals())


def update(name, resource_group, account_name=None, allowed_tenant_ids=None, collaboration_branch=None, host_name=None, key_name=None, no_wait=None, project_name=None, repository_name=None, repository_type=None, root_folder=None, sql_admin_login_password=None, tags=None, tenant_id=None):
    '''
    Update a Synapse workspace.
    '''
    return call_az("az synapse workspace update", locals())


def check_name(name):
    '''
    Check if a Synapse workspace name is available or not.
    '''
    return call_az("az synapse workspace check-name", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    Delete a Synapse workspace.
    '''
    return call_az("az synapse workspace delete", locals())


def activate(key_identifier, name, resource_group, workspace_name, no_wait=None):
    '''
    Activates a workspace and change it's state from pending to success state when the workspace is first being provisioned and double encryption is enabled.
    '''
    return call_az("az synapse workspace activate", locals())


def wait(resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the workspace is met.
    '''
    return call_az("az synapse workspace wait", locals())




from .... pyaz_utils import call_az
from . import keys


def create(name, namespace_name, resource_group, rights=None):
    '''
    Create Authorization Rule for the given Service Bus Namespace
    '''
    return call_az("az servicebus namespace authorization-rule create", locals())


def show(name, namespace_name, resource_group):
    '''
    Shows the details of Service Bus Namespace Authorization Rule
    '''
    return call_az("az servicebus namespace authorization-rule show", locals())


def list(namespace_name, resource_group):
    '''
    Shows the list of Authorization Rule by Service Bus Namespace
    '''
    return call_az("az servicebus namespace authorization-rule list", locals())


def delete(name, namespace_name, resource_group):
    '''
    Deletes the Authorization Rule of the Service Bus Namespace.
    '''
    return call_az("az servicebus namespace authorization-rule delete", locals())


def update(name, namespace_name, resource_group, rights, add=None, force_string=None, remove=None, set=None):
    '''
    Updates Authorization Rule for the given Service Bus Namespace
    '''
    return call_az("az servicebus namespace authorization-rule update", locals())




from .... pyaz_utils import call_az
from . import keys


def list(alias, namespace_name, resource_group):
    '''
    List of Authorizationrule by EventHubs Namespace
    '''
    return call_az("az eventhubs georecovery-alias authorization-rule list", locals())


def show(alias, name, namespace_name, resource_group):
    '''
    Show properties of EventHubs Geo-Disaster Recovery Configuration Alias and Namespace Authorizationrule
    '''
    return call_az("az eventhubs georecovery-alias authorization-rule show", locals())




from ... pyaz_utils import call_az

def list(application_name, cluster_name, resource_group):
    '''
    List services of a given application.
    '''
    return call_az("az sf service list", locals())


def delete(application_name, cluster_name, name, resource_group):
    '''
    Delete a service.
    '''
    return call_az("az sf service delete", locals())


def show(application_name, cluster_name, name, resource_group):
    '''
    Get a service.
    '''
    return call_az("az sf service show", locals())


def create(application, cluster_name, name, resource_group, service_type, state, default_move_cost=None, instance_count=None, min_replica_set_size=None, partition_scheme=None, target_replica_set_size=None):
    '''
    Create a new service on an Azure Service Fabric cluster.
    '''
    return call_az("az sf service create", locals())




from ... pyaz_utils import call_az

def show(resource_group, rollout_name, retry_attempt=None):
    '''
    Gets the rollout.
    '''
    return call_az("az deploymentmanager rollout show", locals())


def list(resource_group):
    '''
    List all rollouts in a resource group
    '''
    return call_az("az deploymentmanager rollout list", locals())


def stop(resource_group, rollout_name, yes=None):
    '''
    Stop the rollout.
    '''
    return call_az("az deploymentmanager rollout stop", locals())


def restart(resource_group, rollout_name, skip_succeeded=None, yes=None):
    '''
    Restarts the rollout.
    '''
    return call_az("az deploymentmanager rollout restart", locals())


def delete(resource_group, rollout_name):
    return call_az("az deploymentmanager rollout delete", locals())




from ... pyaz_utils import call_az
from . import rule


def start(name, profile_name, resource_group, no_wait=None):
    '''
    Start a CDN endpoint.
    '''
    return call_az("az cdn endpoint start", locals())


def stop(name, profile_name, resource_group, no_wait=None):
    '''
    Stop a CDN endpoint.
    '''
    return call_az("az cdn endpoint stop", locals())


def delete(name, profile_name, resource_group, no_wait=None):
    '''
    Delete a CDN endpoint.
    '''
    return call_az("az cdn endpoint delete", locals())


def show(name, profile_name, resource_group):
    return call_az("az cdn endpoint show", locals())


def list(profile_name, resource_group):
    '''
    List available endpoints for a CDN.
    '''
    return call_az("az cdn endpoint list", locals())


def load(content_paths, name, profile_name, resource_group, no_wait=None):
    '''
    Pre-load content for a CDN endpoint.
    '''
    return call_az("az cdn endpoint load", locals())


def purge(content_paths, name, profile_name, resource_group, no_wait=None):
    '''
    Purge pre-loaded content for a CDN endpoint.
    '''
    return call_az("az cdn endpoint purge", locals())


def validate_custom_domain(host_name, name, profile_name, resource_group):
    '''
    Validates the custom domain mapping to ensure it maps to the correct CDN endpoint in DNS.
    '''
    return call_az("az cdn endpoint validate-custom-domain", locals())


def create(name, origin, profile_name, resource_group, content_types_to_compress=None, enable_compression=None, location=None, no_http=None, no_https=None, no_wait=None, origin_host_header=None, origin_path=None, query_string_caching_behavior=None, tags=None):
    '''
    Create a named endpoint to connect to a CDN.
    '''
    return call_az("az cdn endpoint create", locals())


def update(name, profile_name, resource_group, add=None, content_types_to_compress=None, default_origin_group=None, enable_compression=None, force_string=None, no_http=None, no_https=None, no_wait=None, origin_host_header=None, origin_path=None, query_string_caching=None, remove=None, set=None, tags=None):
    '''
    Update a CDN endpoint to manage how content is delivered.
    '''
    return call_az("az cdn endpoint update", locals())




from ... pyaz_utils import call_az

def list(account_name, invoice_section_name=None, profile_name=None):
    '''
    List the role assignments for the caller on a billing account. The operation is supported for billing accounts with agreement type Microsoft Partner Agreement or Microsoft Customer Agreement.
    '''
    return call_az("az billing role-assignment list", locals())


def delete(account_name, name, invoice_section_name=None, profile_name=None, yes=None):
    '''
    Delete a role assignment for the caller on a billing account. The operation is supported for billing accounts with agreement type Microsoft Partner Agreement or Microsoft Customer Agreement.
    '''
    return call_az("az billing role-assignment delete", locals())


def show(account_name, name, invoice_section_name=None, profile_name=None):
    '''
    Show the role assignment detail for the caller within different scopes. The operation is supported for billing accounts with agreement type Microsoft Partner Agreement or Microsoft Customer Agreement.
    '''
    return call_az("az billing role-assignment show", locals())




from ... pyaz_utils import call_az

def on():
    '''
    Turn on parameter persistence.
    '''
    return call_az("az config param-persist on", locals())


def off():
    '''
    Turn off parameter persistence.
    '''
    return call_az("az config param-persist off", locals())


def show():
    '''
    Show parameter persistence data.
    '''
    return call_az("az config param-persist show", locals())


def delete(all=None, purge=None, recursive=None, yes=None):
    '''
    Delete parameter persistence data.
    '''
    return call_az("az config param-persist delete", locals())




from ... pyaz_utils import call_az
from . import audit_policy, classification, ledger_digest_uploads, ltr_backup, ltr_policy, op, replica, str_policy, tde, threat_policy


def show_connection_string(client, auth_type=None, name=None, server=None):
    '''
    Generates a connection string to a database.
    '''
    return call_az("az sql db show-connection-string", locals())


def create(name, resource_group, server, auto_pause_delay=None, backup_storage_redundancy=None, capacity=None, catalog_collation=None, collation=None, compute_model=None, elastic_pool=None, family=None, ledger_on=None, license_type=None, maint_config_id=None, max_size=None, min_capacity=None, no_wait=None, read_replicas=None, read_scale=None, sample_name=None, service_objective=None, tags=None, tier=None, yes=None, zone_redundant=None):
    '''
    Create a database.
    '''
    return call_az("az sql db create", locals())


def copy(dest_name, name, resource_group, server, auto_pause_delay=None, backup_storage_redundancy=None, capacity=None, compute_model=None, dest_resource_group=None, dest_server=None, elastic_pool=None, family=None, license_type=None, min_capacity=None, no_wait=None, read_replicas=None, read_scale=None, service_objective=None, tags=None, zone_redundant=None):
    '''
    Create a copy of a database.
    '''
    return call_az("az sql db copy", locals())


def restore(dest_name, name, resource_group, server, auto_pause_delay=None, backup_storage_redundancy=None, capacity=None, compute_model=None, deleted_time=None, elastic_pool=None, family=None, license_type=None, min_capacity=None, no_wait=None, read_replicas=None, read_scale=None, service_objective=None, tags=None, tier=None, time=None, zone_redundant=None):
    '''
    Create a new database by restoring from a backup.
    '''
    return call_az("az sql db restore", locals())


def rename(name, new_name, resource_group, server):
    '''
    Rename a database.
    '''
    return call_az("az sql db rename", locals())


def show(name, resource_group, server):
    '''
    Get the details for a database.
    '''
    return call_az("az sql db show", locals())


def list(resource_group, server, elastic_pool=None):
    '''
    List databases on a server or elastic pool.
    '''
    return call_az("az sql db list", locals())


def delete(name, resource_group, server, no_wait=None, yes=None):
    '''
    Delete a database.
    '''
    return call_az("az sql db delete", locals())


def update(name, resource_group, server, add=None, auto_pause_delay=None, backup_storage_redundancy=None, capacity=None, compute_model=None, elastic_pool=None, family=None, force_string=None, maint_config_id=None, max_size=None, min_capacity=None, no_wait=None, read_replicas=None, read_scale=None, remove=None, service_objective=None, set=None, tier=None, zone_redundant=None):
    '''
    Update a database.
    '''
    return call_az("az sql db update", locals())


def export(admin_password, admin_user, name, resource_group, server, storage_key, storage_key_type, storage_uri, auth_type=None):
    '''
    Export a database to a bacpac.
    '''
    return call_az("az sql db export", locals())


def import_(admin_password, admin_user, name, resource_group, server, storage_key, storage_key_type, storage_uri, auth_type=None):
    '''
    Imports a bacpac into an existing database.
    '''
    return call_az("az sql db import", locals())


def list_editions(location, available=None, dtu=None, service_objective=None, show_details=None, tier=None, vcores=None):
    '''
    Show database editions available for the currently active subscription.
    '''
    return call_az("az sql db list-editions", locals())


def list_deleted(resource_group, server):
    return call_az("az sql db list-deleted", locals())


def list_usages(name, resource_group, server):
    return call_az("az sql db list-usages", locals())




from .... pyaz_utils import call_az
from . import keys


def create(name, namespace_name, resource_group, topic_name, rights=None):
    '''
    Create Authorization Rule for given Service Bus Topic
    '''
    return call_az("az servicebus topic authorization-rule create", locals())


def show(name, namespace_name, resource_group, topic_name):
    '''
    Shows the details of Authorization Rule for given Service Bus Topic
    '''
    return call_az("az servicebus topic authorization-rule show", locals())


def list(namespace_name, resource_group, topic_name):
    '''
    shows list of Authorization Rule by Service Bus Topic
    '''
    return call_az("az servicebus topic authorization-rule list", locals())


def delete(name, namespace_name, resource_group, topic_name):
    '''
    Deletes the Authorization Rule of the given Service Bus Topic.
    '''
    return call_az("az servicebus topic authorization-rule delete", locals())


def update(name, namespace_name, resource_group, rights, topic_name, add=None, force_string=None, remove=None, set=None):
    '''
    Create Authorization Rule for given Service Bus Topic
    '''
    return call_az("az servicebus topic authorization-rule update", locals())




from ... pyaz_utils import call_az

def list(registry, resource_group=None):
    '''
    List the taskruns for an Azure Container Registry.
    '''
    return call_az("az acr taskrun list", locals())


def delete(name, registry, resource_group=None, yes=None):
    '''
    Delete a taskrun from an Azure Container Registry.
    '''
    return call_az("az acr taskrun delete", locals())


def show(name, registry, resource_group=None):
    '''
    Get the properties of a named taskrun for an Azure Container Registry.
    '''
    return call_az("az acr taskrun show", locals())


def logs(name, registry, resource_group=None):
    '''
    Show run logs for a particular taskrun.
    '''
    return call_az("az acr taskrun logs", locals())




from .... pyaz_utils import call_az

def list(application_name, gallery_name, resource_group):
    return call_az("az sig gallery-application version list", locals())


def show(application_name, gallery_name, name, resource_group, expand=None):
    return call_az("az sig gallery-application version show", locals())


def create(application_name, gallery_name, install_command, name, package_file_link, remove_command, resource_group, default_file_link=None, end_of_life_date=None, exclude_from=None, location=None, no_wait=None, tags=None, target_regions=None, update_command=None):
    '''
    Create a gallery Application Version.
    '''
    return call_az("az sig gallery-application version create", locals())


def update(application_name, gallery_name, name, package_file_link, resource_group, default_file_link=None, end_of_life_date=None, exclude_from=None, location=None, no_wait=None, tags=None, target_regions=None):
    '''
    Update a gallery Application Version.
    '''
    return call_az("az sig gallery-application version update", locals())


def delete(application_name, gallery_name, name, resource_group, no_wait=None, yes=None):
    return call_az("az sig gallery-application version delete", locals())




from ... pyaz_utils import call_az

def create(name, resource_group, sku, capacity=None, location=None, no_wait=None):
    '''
    Create a Kusto cluster.
    '''
    return call_az("az kusto cluster create", locals())


def stop(name, resource_group, no_wait=None):
    '''
    Stop a Kusto cluster.
    '''
    return call_az("az kusto cluster stop", locals())


def start(name, resource_group, no_wait=None):
    '''
    Start a Kusto cluster.
    '''
    return call_az("az kusto cluster start", locals())


def list(resource_group):
    '''
    List a Kusto cluster.
    '''
    return call_az("az kusto cluster list", locals())


def show(name, resource_group):
    '''
    Get a Kusto cluster.
    '''
    return call_az("az kusto cluster show", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete a Kusto cluster.
    '''
    return call_az("az kusto cluster delete", locals())


def update(name, resource_group, add=None, capacity=None, force_string=None, remove=None, set=None, sku=None):
    '''
    Update a Kusto cluster.
    '''
    return call_az("az kusto cluster update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Wait for a managed Kusto cluster to reach a desired state.
    '''
    return call_az("az kusto cluster wait", locals())




from .... pyaz_utils import call_az

def show(account_name, backup_policy_name, resource_group):
    '''
    Get the specified ANF backup policy.
    '''
    return call_az("az netappfiles account backup-policy show", locals())


def list(account_name, resource_group):
    '''
    List the ANF backup policy for the specified account.
    '''
    return call_az("az netappfiles account backup-policy list", locals())


def delete(account_name, backup_policy_name, resource_group):
    '''
    Delete the specified ANF backup policy.
    '''
    return call_az("az netappfiles account backup-policy delete", locals())


def update(account_name, backup_policy_name, resource_group, daily_backups=None, enabled=None, location=None, monthly_backups=None, tags=None, weekly_backups=None):
    '''
    Update the specified ANF backup policy.
    '''
    return call_az("az netappfiles account backup-policy update", locals())


def create(account_name, backup_policy_name, location, resource_group, daily_backups=None, enabled=None, monthly_backups=None, tags=None, weekly_backups=None):
    '''
    Create a new Azure NetApp Files (ANF) backup policy.
    '''
    return call_az("az netappfiles account backup-policy create", locals())




from ... pyaz_utils import call_az

def query_by_workspace(last_updated_after, last_updated_before, workspace_name, continuation_token=None, filters=None, order_by=None):
    '''
    Query pipeline runs in the workspace based on input filter conditions.
    '''
    return call_az("az synapse pipeline-run query-by-workspace", locals())


def show(run_id, workspace_name):
    '''
    Get a pipeline run by its run ID.
    '''
    return call_az("az synapse pipeline-run show", locals())


def cancel(run_id, workspace_name, is_recursive=None, yes=None):
    '''
    Cancel a pipeline run by its run ID.
    '''
    return call_az("az synapse pipeline-run cancel", locals())




from ... pyaz_utils import call_az
from . import authorization_rule


def set(alias, namespace_name, partner_namespace, resource_group, alternate_name=None):
    '''
    Sets a Geo-Disaster Recovery Configuration Alias for the give Namespace
    '''
    return call_az("az eventhubs georecovery-alias set", locals())


def show(alias, namespace_name, resource_group):
    '''
    shows properties of Geo-Disaster Recovery Configuration Alias for Primay or Secondary Namespace
    '''
    return call_az("az eventhubs georecovery-alias show", locals())


def list(namespace_name, resource_group):
    return call_az("az eventhubs georecovery-alias list", locals())


def break_pair(alias, namespace_name, resource_group):
    '''
    Disables Geo-Disaster Recovery Configuration Alias and stops replicating changes from primary to secondary namespaces
    '''
    return call_az("az eventhubs georecovery-alias break-pair", locals())


def fail_over(alias, namespace_name, resource_group):
    '''
    Invokes Geo-Disaster Recovery Configuration Alias to point to the secondary namespace
    '''
    return call_az("az eventhubs georecovery-alias fail-over", locals())


def exists(alias, namespace_name, resource_group):
    '''
    Check the availability of Geo-Disaster Recovery Configuration Alias Name
    '''
    return call_az("az eventhubs georecovery-alias exists", locals())


def delete(alias, namespace_name, resource_group):
    '''
    Delete Geo-Disaster Recovery Configuration Alias
    '''
    return call_az("az eventhubs georecovery-alias delete", locals())




from ... pyaz_utils import call_az

def delete(name, resource_group, no_wait=None):
    '''
    Delete a local VPN gateway.
    '''
    return call_az("az network local-gateway delete", locals())


def show(name, resource_group):
    '''
    Get the details of a local VPN gateway.
    '''
    return call_az("az network local-gateway show", locals())


def list(resource_group):
    '''
    List all local VPN gateways in a resource group.
    '''
    return call_az("az network local-gateway list", locals())


def create(gateway_ip_address, name, resource_group, asn=None, bgp_peering_address=None, local_address_prefixes=None, location=None, no_wait=None, peer_weight=None, tags=None):
    '''
    Create a local VPN gateway.
    '''
    return call_az("az network local-gateway create", locals())


def update(name, resource_group, add=None, asn=None, bgp_peering_address=None, force_string=None, gateway_ip_address=None, local_address_prefixes=None, no_wait=None, peer_weight=None, remove=None, set=None, tags=None):
    '''
    Update a local VPN gateway.
    '''
    return call_az("az network local-gateway update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the local gateway is met.
    '''
    return call_az("az network local-gateway wait", locals())




from .... pyaz_utils import call_az

def list(account_endpoint=None, account_key=None, account_name=None):
    '''
    Lists all of the applications available in the specified account.
    '''
    return call_az("az batch application summary list", locals())


def show(application_id, account_endpoint=None, account_key=None, account_name=None):
    '''
    Gets information about the specified application.
    '''
    return call_az("az batch application summary show", locals())




from .... pyaz_utils import call_az

def show(account, database_name, schema_name, view_name):
    return call_az("az dla catalog view show", locals())


def list(account, database_name, schema_name=None):
    '''
    List views in a database or schema.
    '''
    return call_az("az dla catalog view list", locals())




from ... pyaz_utils import call_az
from . import copy, immutability_policy, incremental_copy, lease, metadata


def show(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, lease_id=None, sas_token=None, snapshot=None, tags_condition=None, timeout=None):
    '''
    Get the details of a blob.
    '''
    return call_az("az storage blob show", locals())


def set_tier(container_name, name, tier, account_key=None, account_name=None, auth_mode=None, connection_string=None, rehydrate_priority=None, sas_token=None, timeout=None, type=None):
    '''
    Set the block or page tiers on the blob.
    '''
    return call_az("az storage blob set-tier", locals())


def list(container_name, account_key=None, account_name=None, auth_mode=None, connection_string=None, delimiter=None, include=None, marker=None, num_results=None, prefix=None, sas_token=None, show_next_marker=None, timeout=None):
    '''
    List blobs in a given container.
    '''
    return call_az("az storage blob list", locals())


def query(container_name, name, query_expression, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, in_column_separator=None, in_escape_char=None, in_has_header=None, in_line_separator=None, in_quote_char=None, in_record_separator=None, input_format=None, lease_id=None, out_column_separator=None, out_escape_char=None, out_has_header=None, out_line_separator=None, out_quote_char=None, out_record_separator=None, output_format=None, result_file=None, sas_token=None, tags_condition=None, timeout=None):
    '''
    Enable users to select/project on blob or blob snapshot data by providing simple query expressions.
    '''
    return call_az("az storage blob query", locals())


def rewrite(container_name, name, source_uri, account_key=None, account_name=None, auth_mode=None, connection_string=None, encryption_scope=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, lease_id=None, sas_token=None, tags_condition=None, tier=None, timeout=None):
    '''
    Create a new Block Blob where the content of the blob is read from a given URL.
    '''
    return call_az("az storage blob rewrite", locals())


def set_legal_hold(container_name, legal_hold, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    Set blob legal hold.
    '''
    return call_az("az storage blob set-legal-hold", locals())


def download(container_name, file, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, end_range=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, lease_id=None, max_connections=None, no_progress=None, open_mode=None, sas_token=None, snapshot=None, socket_timeout=None, start_range=None, timeout=None, validate_content=None):
    return call_az("az storage blob download", locals())


def generate_sas(container_name, name, account_key=None, account_name=None, as_user=None, auth_mode=None, cache_control=None, connection_string=None, content_disposition=None, content_encoding=None, content_language=None, content_type=None, expiry=None, full_uri=None, https_only=None, ip=None, permissions=None, policy_name=None, start=None):
    '''
    Generate a shared access signature for the blob.
    '''
    return call_az("az storage blob generate-sas", locals())


def url(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, protocol=None, sas_token=None, snapshot=None):
    '''
    Create the url to access a blob.
    '''
    return call_az("az storage blob url", locals())


def snapshot(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, lease_id=None, metadata=None, sas_token=None, timeout=None):
    return call_az("az storage blob snapshot", locals())


def update(container_name, name, account_key=None, account_name=None, auth_mode=None, clear_content_settings=None, connection_string=None, content_cache_control=None, content_disposition=None, content_encoding=None, content_language=None, content_md5=None, content_type=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, lease_id=None, sas_token=None, timeout=None):
    return call_az("az storage blob update", locals())


def exists(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, snapshot=None, timeout=None):
    '''
    Check for the existence of a blob in a container.
    '''
    return call_az("az storage blob exists", locals())


def delete(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, delete_snapshots=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, lease_id=None, sas_token=None, snapshot=None, timeout=None):
    '''
    Mark a blob or snapshot for deletion.
    '''
    return call_az("az storage blob delete", locals())


def undelete(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    return call_az("az storage blob undelete", locals())


def upload(container_name, file, account_key=None, account_name=None, auth_mode=None, connection_string=None, content_cache_control=None, content_disposition=None, content_encoding=None, content_language=None, content_md5=None, content_type=None, encryption_scope=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, lease_id=None, max_connections=None, maxsize_condition=None, metadata=None, name=None, no_progress=None, sas_token=None, socket_timeout=None, tier=None, timeout=None, type=None, validate_content=None):
    '''
    Upload a file to a storage blob.
    '''
    return call_az("az storage blob upload", locals())


def upload_batch(destination, source, account_key=None, account_name=None, auth_mode=None, connection_string=None, content_cache_control=None, content_disposition=None, content_encoding=None, content_language=None, content_md5=None, content_type=None, destination_path=None, dryrun=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, lease_id=None, max_connections=None, maxsize_condition=None, metadata=None, no_progress=None, pattern=None, sas_token=None, socket_timeout=None, timeout=None, type=None, validate_content=None):
    '''
    Upload files from a local directory to a blob container.
    '''
    return call_az("az storage blob upload-batch", locals())


def download_batch(destination, source, account_key=None, account_name=None, auth_mode=None, connection_string=None, dryrun=None, max_connections=None, no_progress=None, pattern=None, sas_token=None, socket_timeout=None):
    '''
    Download blobs from a blob container recursively.
    '''
    return call_az("az storage blob download-batch", locals())


def delete_batch(source, account_key=None, account_name=None, auth_mode=None, connection_string=None, delete_snapshots=None, dryrun=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, lease_id=None, pattern=None, sas_token=None, timeout=None):
    '''
    Delete blobs from a blob container recursively.
    '''
    return call_az("az storage blob delete-batch", locals())


def restore(account_name, time_to_restore, blob_range=None, no_wait=None, resource_group=None):
    '''
    Restore blobs in the specified blob ranges.
    '''
    return call_az("az storage blob restore", locals())


def sync(container, source, account_key=None, account_name=None, auth_mode=None, connection_string=None, destination=None, exclude_path=None, exclude_pattern=None, include_pattern=None, sas_token=None):
    '''
    Sync blobs recursively to a storage blob container.
    '''
    return call_az("az storage blob sync", locals())




from .... pyaz_utils import call_az

def show(account_name, backup_name, pool_name, resource_group, volume_name):
    '''
    Get the specified ANF Backup.
    '''
    return call_az("az netappfiles volume backup show", locals())


def list(account_name, pool_name, resource_group, volume_name):
    '''
    List the ANF Backups for the specified volume.
    '''
    return call_az("az netappfiles volume backup list", locals())


def delete(account_name, backup_name, pool_name, resource_group, volume_name):
    return call_az("az netappfiles volume backup delete", locals())


def status(account_name, pool_name, resource_group, volume_name):
    '''
    Get backup status of the specified ANF Volume.
    '''
    return call_az("az netappfiles volume backup status", locals())


def restore_status(account_name, pool_name, resource_group, volume_name):
    '''
    Get backup restore status of the specified ANF Volume.
    '''
    return call_az("az netappfiles volume backup restore-status", locals())


def update(account_name, backup_name, pool_name, resource_group, volume_name, label=None, tags=None, use_existing_snapshot=None):
    '''
    Update the specified ANF backup with the values provided.
    '''
    return call_az("az netappfiles volume backup update", locals())


def create(account_name, backup_name, location, pool_name, resource_group, volume_name, use_existing_snapshot=None):
    '''
    Create specified ANF volume backup.
    '''
    return call_az("az netappfiles volume backup create", locals())




from .... pyaz_utils import call_az

def delete(assignee=None, assignee_object_id=None, hsm_name=None, id=None, ids=None, name=None, role=None, scope=None):
    return call_az("az keyvault role assignment delete", locals())


def list(assignee=None, assignee_object_id=None, hsm_name=None, id=None, role=None, scope=None):
    return call_az("az keyvault role assignment list", locals())


def create(role, scope, assignee=None, assignee_object_id=None, assignee_principal_type=None, hsm_name=None, id=None, name=None):
    return call_az("az keyvault role assignment create", locals())




from ... pyaz_utils import call_az
from . import authorization_rule, consumer_group


def create(name, namespace_name, resource_group, archive_name_format=None, blob_container=None, capture_interval=None, capture_size_limit=None, destination_name=None, enable_capture=None, message_retention=None, partition_count=None, skip_empty_archives=None, status=None, storage_account=None):
    '''
    Creates the EventHubs Eventhub
    '''
    return call_az("az eventhubs eventhub create", locals())


def show(name, namespace_name, resource_group):
    '''
    shows the Eventhub Details
    '''
    return call_az("az eventhubs eventhub show", locals())


def list(namespace_name, resource_group, skip=None, top=None):
    '''
    List the EventHub by Namespace
    '''
    return call_az("az eventhubs eventhub list", locals())


def delete(name, namespace_name, resource_group):
    '''
    Deletes the Eventhub
    '''
    return call_az("az eventhubs eventhub delete", locals())


def update(name, namespace_name, resource_group, add=None, archive_name_format=None, blob_container=None, capture_interval=None, capture_size_limit=None, destination_name=None, enable_capture=None, force_string=None, message_retention=None, partition_count=None, remove=None, set=None, skip_empty_archives=None, status=None, storage_account=None):
    '''
    Updates the EventHubs Eventhub
    '''
    return call_az("az eventhubs eventhub update", locals())




from .... pyaz_utils import call_az

def list(lb_name, resource_group):
    '''
    List inbound NAT address pools.
    '''
    return call_az("az network lb inbound-nat-pool list", locals())


def show(lb_name, name, resource_group):
    '''
    Get the details of an inbound NAT address pool.
    '''
    return call_az("az network lb inbound-nat-pool show", locals())


def delete(lb_name, name, resource_group):
    '''
    Delete an inbound NAT address pool.
    '''
    return call_az("az network lb inbound-nat-pool delete", locals())


def create(backend_port, frontend_port_range_end, frontend_port_range_start, lb_name, name, protocol, resource_group, enable_tcp_reset=None, floating_ip=None, frontend_ip_name=None, idle_timeout=None):
    '''
    Create an inbound NAT address pool.
    '''
    return call_az("az network lb inbound-nat-pool create", locals())


def update(lb_name, name, resource_group, add=None, backend_port=None, enable_tcp_reset=None, floating_ip=None, force_string=None, frontend_ip_name=None, frontend_port_range_end=None, frontend_port_range_start=None, idle_timeout=None, protocol=None, remove=None, set=None):
    '''
    Update an inbound NAT address pool.
    '''
    return call_az("az network lb inbound-nat-pool update", locals())




from .... pyaz_utils import call_az

def add(dh_group, gateway_name, ike_encryption, ike_integrity, ipsec_encryption, ipsec_integrity, pfs_group, resource_group, sa_lifetime, sa_max_size, no_wait=None):
    '''
    Add a virtual network gateway IPSec policy.
    '''
    return call_az("az network vnet-gateway ipsec-policy add", locals())


def list(gateway_name, resource_group):
    '''
    List IPSec policies associated with a virtual network gateway.
    '''
    return call_az("az network vnet-gateway ipsec-policy list", locals())


def clear(gateway_name, resource_group, no_wait=None):
    '''
    Delete all IPsec policies on a virtual network gateway.
    '''
    return call_az("az network vnet-gateway ipsec-policy clear", locals())




from ..... pyaz_utils import call_az

def add(address_pool, ip_config_name, nic_name, resource_group, gateway_name=None, lb_name=None):
    '''
    Add an address pool to an IP configuration.
    '''
    return call_az("az network nic ip-config address-pool add", locals())


def remove(address_pool, ip_config_name, nic_name, resource_group, gateway_name=None, lb_name=None):
    '''
    Remove an address pool of an IP configuration.
    '''
    return call_az("az network nic ip-config address-pool remove", locals())




from .. pyaz_utils import call_az
from . import builder


def create(name, resource_group, source, data_disk_caching=None, data_disk_sources=None, edge_zone=None, hyper_v_generation=None, location=None, os_disk_caching=None, os_type=None, storage_sku=None, tags=None, zone_resilient=None):
    '''
    Create a custom Virtual Machine Image from managed disks or snapshots.
    '''
    return call_az("az image create", locals())


def list(resource_group=None):
    '''
    List custom VM images.
    '''
    return call_az("az image list", locals())


def show(name, resource_group, expand=None):
    return call_az("az image show", locals())


def delete(name, resource_group):
    return call_az("az image delete", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Update custom VM images.
    '''
    return call_az("az image update", locals())




from ... pyaz_utils import call_az
from . import file, remote_desktop, remote_login_settings, scheduling, service_logs, user


def delete(pool_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, json_file=None, node_deallocation_option=None, node_list=None, resize_timeout=None):
    return call_az("az batch node delete", locals())


def show(node_id, pool_id, account_endpoint=None, account_key=None, account_name=None, select=None):
    return call_az("az batch node show", locals())


def list(pool_id, account_endpoint=None, account_key=None, account_name=None, filter=None, select=None):
    return call_az("az batch node list", locals())


def reboot(node_id, pool_id, account_endpoint=None, account_key=None, account_name=None, node_reboot_option=None):
    return call_az("az batch node reboot", locals())


def reimage(node_id, pool_id, account_endpoint=None, account_key=None, account_name=None, node_reimage_option=None):
    return call_az("az batch node reimage", locals())




from ... pyaz_utils import call_az

def put(content, queue_name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, time_to_live=None, timeout=None, visibility_timeout=None):
    return call_az("az storage message put", locals())


def get(queue_name, account_key=None, account_name=None, auth_mode=None, connection_string=None, num_messages=None, sas_token=None, timeout=None, visibility_timeout=None):
    return call_az("az storage message get", locals())


def peek(queue_name, account_key=None, account_name=None, auth_mode=None, connection_string=None, num_messages=None, sas_token=None, timeout=None):
    return call_az("az storage message peek", locals())


def delete(id, pop_receipt, queue_name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    return call_az("az storage message delete", locals())


def clear(queue_name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    return call_az("az storage message clear", locals())


def update(id, pop_receipt, queue_name, visibility_timeout, account_key=None, account_name=None, auth_mode=None, connection_string=None, content=None, sas_token=None, timeout=None):
    return call_az("az storage message update", locals())




from .... pyaz_utils import call_az
from . import predefined


def set(gateway_name, resource_group, cipher_suites=None, disabled_ssl_protocols=None, min_protocol_version=None, name=None, no_wait=None, policy_type=None):
    '''
    Update or clear SSL policy settings.
    '''
    return call_az("az network application-gateway ssl-policy set", locals())


def show(gateway_name, resource_group):
    '''
    Get the details of gateway's SSL policy settings.
    '''
    return call_az("az network application-gateway ssl-policy show", locals())


def list_options():
    '''
    Lists available SSL options for configuring SSL policy.
    '''
    return call_az("az network application-gateway ssl-policy list-options", locals())




from .... pyaz_utils import call_az

def create(circuit_name, name, resource_group):
    '''
    Create a new link authorization for an ExpressRoute circuit.
    '''
    return call_az("az network express-route auth create", locals())


def delete(circuit_name, name, resource_group):
    '''
    Delete a link authorization of an ExpressRoute circuit.
    '''
    return call_az("az network express-route auth delete", locals())


def show(circuit_name, name, resource_group):
    '''
    Get the details of a link authorization of an ExpressRoute circuit.
    '''
    return call_az("az network express-route auth show", locals())


def list(circuit_name, resource_group):
    '''
    List link authorizations of an ExpressRoute circuit.
    '''
    return call_az("az network express-route auth list", locals())




from ... pyaz_utils import call_az
from . import ad_admin, configuration, firewall_rule, key, private_endpoint_connection, private_link_resource, replica, vnet_rule


def create(admin_password=None, admin_user=None, assign_identity=None, auto_grow=None, backup_retention=None, geo_redundant_backup=None, infrastructure_encryption=None, location=None, minimal_tls_version=None, name=None, public_network_access=None, resource_group=None, sku_name=None, ssl_enforcement=None, storage_size=None, tags=None, version=None):
    '''
    Create a server.
    '''
    return call_az("az postgres server create", locals())


def restore(name, resource_group, restore_point_in_time, source_server, no_wait=None):
    '''
    Restore a server from backup.
    '''
    return call_az("az postgres server restore", locals())


def georestore(location, name, resource_group, source_server, backup_retention=None, geo_redundant_backup=None, no_wait=None, sku_name=None):
    '''
    Geo-restore a server from backup.
    '''
    return call_az("az postgres server georestore", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete a server.
    '''
    return call_az("az postgres server delete", locals())


def show(name, resource_group):
    '''
    Get the details of a server.
    '''
    return call_az("az postgres server show", locals())


def list(resource_group=None):
    '''
    List available servers.
    '''
    return call_az("az postgres server list", locals())


def update(name, resource_group, add=None, admin_password=None, assign_identity=None, auto_grow=None, backup_retention=None, force_string=None, minimal_tls_version=None, public_network_access=None, remove=None, set=None, sku_name=None, ssl_enforcement=None, storage_size=None, tags=None):
    '''
    Update a server.
    '''
    return call_az("az postgres server update", locals())


def wait(name, resource_group, custom=None, exists=None, interval=None, timeout=None):
    '''
    Wait for server to satisfy certain conditions.
    '''
    return call_az("az postgres server wait", locals())


def restart(name, resource_group):
    '''
    Restart a server.
    '''
    return call_az("az postgres server restart", locals())


def list_skus(location):
    '''
    List available sku's in the given region.
    '''
    return call_az("az postgres server list-skus", locals())


def show_connection_string(admin_password=None, admin_user=None, database_name=None, server_name=None):
    '''
    Show the connection strings for a PostgreSQL server database.
    '''
    return call_az("az postgres server show-connection-string", locals())




from .... pyaz_utils import call_az

def list(dps_name, resource_group):
    '''
    List all linked IoT hubs in an Azure IoT Hub device provisioning service.
    '''
    return call_az("az iot dps linked-hub list", locals())


def show(dps_name, linked_hub, resource_group):
    '''
    Show details of a linked IoT hub in an Azure IoT Hub device provisioning service.
    '''
    return call_az("az iot dps linked-hub show", locals())


def create(connection_string, dps_name, location, resource_group, allocation_weight=None, apply_allocation_policy=None, no_wait=None):
    '''
    Create a linked IoT hub in an Azure IoT Hub device provisioning service.
    '''
    return call_az("az iot dps linked-hub create", locals())


def update(dps_name, linked_hub, resource_group, allocation_weight=None, apply_allocation_policy=None, no_wait=None):
    '''
    Update a linked IoT hub in an Azure IoT Hub device provisioning service.
    '''
    return call_az("az iot dps linked-hub update", locals())


def delete(dps_name, linked_hub, resource_group, no_wait=None):
    '''
    Update a linked IoT hub in an Azure IoT Hub device provisioning service.
    '''
    return call_az("az iot dps linked-hub delete", locals())




from ... pyaz_utils import call_az

def show(profile_name, resource_group, security_policy_name):
    return call_az("az afd security-policy show", locals())


def list(profile_name, resource_group):
    return call_az("az afd security-policy list", locals())


def create(domains, profile_name, resource_group, security_policy_name, waf_policy):
    '''
    Creates a new security policy within the specified profile.
    '''
    return call_az("az afd security-policy create", locals())


def update(profile_name, resource_group, security_policy_name, domains=None, waf_policy=None):
    '''
    Update an existing security policy within the specified profile.
    '''
    return call_az("az afd security-policy update", locals())


def delete(profile_name, resource_group, security_policy_name, yes=None):
    return call_az("az afd security-policy delete", locals())




from ... pyaz_utils import call_az
from . import package, summary


def list(name, resource_group, maxresults=None):
    return call_az("az batch application list", locals())


def show(application_name, name, resource_group):
    return call_az("az batch application show", locals())


def create(application_name, name, resource_group, parameters=None):
    return call_az("az batch application create", locals())


def set(application_name, name, resource_group, allow_updates=None, default_version=None, display_name=None):
    '''
    Update properties for a Batch application.
    '''
    return call_az("az batch application set", locals())


def delete(application_name, name, resource_group, yes=None):
    return call_az("az batch application delete", locals())




from .... pyaz_utils import call_az
from . import event_grid, event_hub, iot_hub


def list(database_name, kusto_pool_name, resource_group, workspace_name):
    '''
    Returns the list of data connections of the given Kusto pool database.
    '''
    return call_az("az synapse kusto data-connection list", locals())


def show(data_connection_name, database_name, kusto_pool_name, resource_group, workspace_name):
    '''
    Returns a data connection.
    '''
    return call_az("az synapse kusto data-connection show", locals())


def delete(data_connection_name, database_name, kusto_pool_name, resource_group, workspace_name, no_wait=None, yes=None):
    '''
    Deletes the data connection with the given name.
    '''
    return call_az("az synapse kusto data-connection delete", locals())


def wait(data_connection_name, database_name, kusto_pool_name, resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the synapse kusto data-connection is met.
    '''
    return call_az("az synapse kusto data-connection wait", locals())




from ..... pyaz_utils import call_az

def list(port_name, resource_group):
    '''
    List ExpressRoute links.
    '''
    return call_az("az network express-route port link list", locals())


def show(name, port_name, resource_group):
    '''
    Get the details of an ExpressRoute link.
    '''
    return call_az("az network express-route port link show", locals())


def update(name, port_name, resource_group, add=None, admin_state=None, force_string=None, macsec_cak_secret_identifier=None, macsec_cipher=None, macsec_ckn_secret_identifier=None, macsec_sci_state=None, no_wait=None, remove=None, set=None):
    '''
    Manage MACsec configuration of an ExpressRoute Link.
    '''
    return call_az("az network express-route port link update", locals())




from .... pyaz_utils import call_az

def add(cluster_name, resource_group, certificate_file=None, certificate_output_folder=None, certificate_password=None, certificate_subject_name=None, secret_identifier=None, vault_name=None, vault_rg=None):
    '''
    Add a new certificate to the Virtual Machine Scale Sets that make up the cluster to be used by hosted applications.
    '''
    return call_az("az sf application certificate add", locals())




from .... pyaz_utils import call_az

def list(instance_id, location):
    '''
    List all the versions of all the mongodb databases that were created / modified / deleted in the given restorable account.
    '''
    return call_az("az cosmosdb mongodb restorable-database list", locals())




from ... pyaz_utils import call_az
from . import policy


def create(name, account_key=None, account_name=None, connection_string=None, fail_on_exist=None, sas_token=None, timeout=None):
    return call_az("az storage table create", locals())


def delete(name, account_key=None, account_name=None, connection_string=None, fail_not_exist=None, sas_token=None, timeout=None):
    return call_az("az storage table delete", locals())


def exists(name, account_key=None, account_name=None, connection_string=None, sas_token=None, timeout=None):
    return call_az("az storage table exists", locals())


def generate_sas(name, account_key=None, account_name=None, connection_string=None, end_pk=None, end_rk=None, expiry=None, https_only=None, ip=None, permissions=None, policy_name=None, start=None, start_pk=None, start_rk=None):
    return call_az("az storage table generate-sas", locals())


def list(account_key=None, account_name=None, connection_string=None, marker=None, num_results=None, sas_token=None, timeout=None):
    '''
    List tables in a storage account.
    '''
    return call_az("az storage table list", locals())


def stats(account_key=None, account_name=None, connection_string=None, sas_token=None, timeout=None):
    return call_az("az storage table stats", locals())




from .... pyaz_utils import call_az

def show(registry, resource_group=None):
    '''
    Show the configured retention policy for an Azure Container Registry.
    '''
    return call_az("az acr config retention show", locals())


def update(registry, type, days=None, resource_group=None, status=None):
    '''
    Update retention policy for an Azure Container Registry.
    '''
    return call_az("az acr config retention update", locals())




from .... pyaz_utils import call_az

def list(name, resource_group, slot=None):
    '''
    Get the details of a web app's settings.
    '''
    return call_az("az webapp config appsettings list", locals())


def set(name, resource_group, settings=None, slot=None, slot_settings=None):
    '''
    Set a web app's settings.
    '''
    return call_az("az webapp config appsettings set", locals())


def delete(name, resource_group, setting_names, slot=None):
    '''
    Delete web app settings.
    '''
    return call_az("az webapp config appsettings delete", locals())




from .... pyaz_utils import call_az

def set(managed_instance, name, resource_group, monthly_retention=None, week_of_year=None, weekly_retention=None, yearly_retention=None):
    '''
    Update long term retention settings for a managed database.
    '''
    return call_az("az sql midb ltr-policy set", locals())


def show(managed_instance, name, resource_group):
    '''
    Show the long term retention policy for a managed database.
    '''
    return call_az("az sql midb ltr-policy show", locals())




from .. pyaz_utils import call_az

def show(name, resource_group, include_colocation_status=None):
    '''
    Get a proximity placement group
    '''
    return call_az("az ppg show", locals())


def create(name, resource_group, location=None, tags=None, type=None):
    '''
    Create a proximity placement group
    '''
    return call_az("az ppg create", locals())


def list(resource_group=None):
    '''
    List proximity placement groups
    '''
    return call_az("az ppg list", locals())


def update(name, resource_group, add=None, force_string=None, include_colocation_status=None, remove=None, set=None):
    '''
    Update a proximity placement group
    '''
    return call_az("az ppg update", locals())


def delete(name, resource_group):
    return call_az("az ppg delete", locals())




from ... pyaz_utils import call_az

def list(billing_period_name=None, end_date=None, start_date=None, top=None):
    '''
    List the marketplace for an Azure subscription within a billing period.
    '''
    return call_az("az consumption marketplace list", locals())




from ... pyaz_utils import call_az

def list(id=None, name=None, resource_group=None, type=None):
    '''
    List all private link resources.
    '''
    return call_az("az network private-link-resource list", locals())




from .. pyaz_utils import call_az

def list(resource_group=None):
    '''
    List all of the SSH public keys.
    '''
    return call_az("az sshkey list", locals())


def show(name, resource_group):
    '''
    Retrieve information about an SSH public key.
    '''
    return call_az("az sshkey show", locals())


def create(name, resource_group, location=None, public_key=None, tags=None):
    '''
    Create a new SSH public key resource.
    '''
    return call_az("az sshkey create", locals())


def update(name, resource_group, public_key=None, tags=None):
    '''
    Update an SSH public key resource.
    '''
    return call_az("az sshkey update", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete an SSH public key.
    '''
    return call_az("az sshkey delete", locals())




from ... pyaz_utils import call_az

def set(app_version_ids, name, resource_group, app_config_overrides=None, order_applications=None):
    '''
    Set appliations for VM.
    '''
    return call_az("az vm application set", locals())


def list(resource_group, vm_name):
    '''
    List applications for VM
    '''
    return call_az("az vm application list", locals())




from .... pyaz_utils import call_az

def update(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_modified_since=None, lease_id=None, metadata=None, sas_token=None, timeout=None):
    return call_az("az storage container metadata update", locals())


def show(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, lease_id=None, sas_token=None, timeout=None):
    return call_az("az storage container metadata show", locals())




from .... pyaz_utils import call_az

def show(id=None, name=None, resource_group=None, scope_name=None):
    '''
    Show a private endpoint connection of a private link scope resource.
    '''
    return call_az("az monitor private-link-scope private-endpoint-connection show", locals())


def list(resource_group, scope_name):
    '''
    List all private endpoint connections of a private link scope resource.
    '''
    return call_az("az monitor private-link-scope private-endpoint-connection list", locals())


def approve(description=None, id=None, name=None, resource_group=None, scope_name=None):
    '''
    Approve a private endpoint connection of a private link scope resource.
    '''
    return call_az("az monitor private-link-scope private-endpoint-connection approve", locals())


def reject(description=None, id=None, name=None, resource_group=None, scope_name=None):
    '''
    Reject a private endpoint connection of a private link scope resource.
    '''
    return call_az("az monitor private-link-scope private-endpoint-connection reject", locals())


def delete(id=None, name=None, resource_group=None, scope_name=None, yes=None):
    '''
    Delete a private endpoint connection of a private link scope resource.
    '''
    return call_az("az monitor private-link-scope private-endpoint-connection delete", locals())




from ... pyaz_utils import call_az

def rerun(name, run_id, workspace_name):
    '''
    Rerun single trigger instance by runId.
    '''
    return call_az("az synapse trigger-run rerun", locals())


def cancel(name, run_id, workspace_name):
    '''
    Cancel a single trigger instance by runId.
    '''
    return call_az("az synapse trigger-run cancel", locals())


def query_by_workspace(last_updated_after, last_updated_before, workspace_name, continuation_token=None, filters=None, order_by=None):
    '''
    Query trigger runs in the workspace based on input filter conditions.
    '''
    return call_az("az synapse trigger-run query-by-workspace", locals())




from .... pyaz_utils import call_az

def start(name, resource_group, filter=None, no_wait=None):
    '''
    Start packet capture on a virtual network gateway.
    '''
    return call_az("az network vnet-gateway packet-capture start", locals())


def stop(name, resource_group, sas_url, no_wait=None):
    '''
    Stop packet capture on a virtual network gateway.
    '''
    return call_az("az network vnet-gateway packet-capture stop", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the vnet gateway packet capture is met.
    '''
    return call_az("az network vnet-gateway packet-capture wait", locals())




from .... pyaz_utils import call_az

def show(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, lease_id=None, sas_token=None, snapshot=None, timeout=None):
    return call_az("az storage blob metadata show", locals())


def update(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, lease_id=None, metadata=None, sas_token=None, timeout=None):
    return call_az("az storage blob metadata update", locals())




from ... pyaz_utils import call_az
from . import route


def create(name, resource_group, disable_bgp_route_propagation=None, location=None, tags=None):
    '''
    Create a route table.
    '''
    return call_az("az network route-table create", locals())


def delete(name, resource_group):
    '''
    Delete a route table.
    '''
    return call_az("az network route-table delete", locals())


def show(name, resource_group, expand=None):
    '''
    Get the details of a route table.
    '''
    return call_az("az network route-table show", locals())


def list(resource_group=None):
    '''
    List route tables.
    '''
    return call_az("az network route-table list", locals())


def update(name, resource_group, add=None, disable_bgp_route_propagation=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Update a route table.
    '''
    return call_az("az network route-table update", locals())




from ... pyaz_utils import call_az
from . import keys


def show(name, resource_group):
    '''
    Show the details of a maps account.
    '''
    return call_az("az maps account show", locals())


def list(resource_group=None):
    '''
    Show all maps accounts in a subscription or in a resource group.
    '''
    return call_az("az maps account list", locals())


def create(name, resource_group, sku, accept_tos=None, disable_local_auth=None, kind=None, linked_resources=None, tags=None, type=None, user_identities=None):
    '''
    Create a Maps Account. A Maps Account holds the keys which allow access to the Maps REST APIs.
    '''
    return call_az("az maps account create", locals())


def delete(name, resource_group):
    '''
    Delete a Maps Account.
    '''
    return call_az("az maps account delete", locals())


def update(name, resource_group, sku, disable_local_auth=None, kind=None, linked_resources=None, tags=None, type=None, user_identities=None):
    '''
    Updates a Maps Account. Only a subset of the parameters may be updated after creation, such as Sku, Tags, Properties.
    '''
    return call_az("az maps account update", locals())




from ... pyaz_utils import call_az

def update(account_name, customer_name=None, marketplace_purchases=None, profile_name=None, reservation_purchases=None, view_charges=None):
    '''
    Update the policies for a billing profile. This operation is supported only for billing accounts with agreement type Microsoft Customer Agreement.
    '''
    return call_az("az billing policy update", locals())


def show(account_name, customer_name=None, profile_name=None):
    '''
    Show the policies for a customer or for a billing profile. This operation is supported only for billing accounts with agreement type Microsoft Partner Agreement."
    '''
    return call_az("az billing policy show", locals())




from .... pyaz_utils import call_az
from . import ag_listener


def update(name, resource_group, add=None, bootstrap_acc=None, domain_fqdn=None, force_string=None, fsw_path=None, operator_acc=None, ou_path=None, remove=None, sa_key=None, service_acc=None, set=None, storage_account=None, tags=None):
    '''
    Updates a SQL virtual machine group if there are not SQL virtual machines attached to the group.
    '''
    return call_az("az sql vm group update", locals())


def show(name, resource_group):
    return call_az("az sql vm group show", locals())


def list(resource_group=None):
    return call_az("az sql vm group list", locals())


def delete(name, resource_group, yes=None):
    return call_az("az sql vm group delete", locals())


def create(domain_fqdn, image_offer, image_sku, name, operator_acc, resource_group, service_acc, storage_account, bootstrap_acc=None, fsw_path=None, location=None, ou_path=None, sa_key=None, tags=None):
    '''
    Creates a SQL virtual machine group.
    '''
    return call_az("az sql vm group create", locals())




from ... pyaz_utils import call_az

def create(appid, name, page_id, resource_group, secret, token, add_disabled=None):
    '''
    Create the Facebook Channel on a bot.
    '''
    return call_az("az bot facebook create", locals())


def show(name, resource_group, with_secrets=None):
    '''
    Get details of the Facebook Channel on a bot
    '''
    return call_az("az bot facebook show", locals())


def delete(name, resource_group):
    '''
    Delete the Facebook Channel on a bot
    '''
    return call_az("az bot facebook delete", locals())




from ... pyaz_utils import call_az

def query_by_pipeline_run(last_updated_after, last_updated_before, name, run_id, workspace_name, continuation_token=None, filters=None, order_by=None):
    '''
    Query activity runs based on input filter conditions.
    '''
    return call_az("az synapse activity-run query-by-pipeline-run", locals())




from ... pyaz_utils import call_az

def show(account_name, name, resource_group):
    '''
    Show the details of an asset.
    '''
    return call_az("az ams asset show", locals())


def list(account_name, resource_group, filter=None, orderby=None, top=None):
    '''
    List all the assets of an Azure Media Services account.
    '''
    return call_az("az ams asset list", locals())


def delete(account_name, name, resource_group):
    '''
    Delete an asset.
    '''
    return call_az("az ams asset delete", locals())


def list_streaming_locators(account_name, name, resource_group):
    '''
    List streaming locators which are associated with this asset.
    '''
    return call_az("az ams asset list-streaming-locators", locals())


def get_encryption_key(account_name, name, resource_group):
    '''
    Get the asset storage encryption keys used to decrypt content created by version 2 of the Media Services API.
    '''
    return call_az("az ams asset get-encryption-key", locals())


def update(account_name, name, resource_group, add=None, alternate_id=None, description=None, force_string=None, remove=None, set=None):
    '''
    Update the details of an asset.
    '''
    return call_az("az ams asset update", locals())


def get_sas_urls(account_name, name, resource_group, expiry=None, permissions=None):
    '''
    Lists storage container URLs with shared access signatures (SAS) for uploading and downloading Asset content. The signatures are derived from the storage account keys.
    '''
    return call_az("az ams asset get-sas-urls", locals())


def create(account_name, name, resource_group, alternate_id=None, container=None, description=None, storage_account=None):
    '''
    Create an asset.
    '''
    return call_az("az ams asset create", locals())




from ... pyaz_utils import call_az

def list(account_name, expand=None):
    '''
    List the billing profiles that a user has access to. The operation is supported for billing accounts with agreement type Microsoft Customer Agreement or Microsoft Partner Agreement.
    '''
    return call_az("az billing profile list", locals())


def show(account_name, name, expand=None):
    '''
    Get a billing profile by its ID. The operation is supported for billing accounts with agreement type Microsoft Customer Agreement or Microsoft Partner Agreement.
    '''
    return call_az("az billing profile show", locals())


def create(account_name, name, bill_to=None, display_name=None, enabled_azure_plans=None, invoice_email_opt_in=None, invoice_sections_value=None, no_wait=None, po_number=None):
    '''
    Creates or updates a billing profile. The operation is supported for billing accounts with agreement type Microsoft Customer Agreement or Microsoft Partner Agreement.
    '''
    return call_az("az billing profile create", locals())


def update(account_name, name, bill_to=None, display_name=None, enabled_azure_plans=None, invoice_email_opt_in=None, invoice_sections_value=None, no_wait=None, po_number=None):
    '''
    Creates or updates a billing profile. The operation is supported for billing accounts with agreement type Microsoft Customer Agreement or Microsoft Partner Agreement.
    '''
    return call_az("az billing profile update", locals())


def wait(account_name, name, created=None, custom=None, deleted=None, exists=None, expand=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the billing profile is met.
    '''
    return call_az("az billing profile wait", locals())




from .... pyaz_utils import call_az

def start(managed_instance, name, resource_group, storage_sas, storage_uri, auto_complete=None, last_backup_name=None, no_wait=None):
    '''
    Start Log Replay service on specified database.
    '''
    return call_az("az sql midb log-replay start", locals())


def stop(managed_instance, name, resource_group, no_wait=None, yes=None):
    '''
    Stop Log Replay service.
    '''
    return call_az("az sql midb log-replay stop", locals())


def complete(managed_instance, name, resource_group, last_backup_name=None):
    '''
    Complete Log Replay service on specified database.
    '''
    return call_az("az sql midb log-replay complete", locals())


def wait(managed_instance, name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the managed database is met.
    '''
    return call_az("az sql midb log-replay wait", locals())


def show(managed_instance, name, resource_group):
    '''
    Get status of Log Replay service.
    '''
    return call_az("az sql midb log-replay show", locals())




from ..... pyaz_utils import call_az

def show(name, resource_group, zone_name, record_type=None):
    '''
    Get the details of a CAA record set.
    '''
    return call_az("az network dns record-set caa show", locals())


def delete(name, resource_group, zone_name, if_match=None, record_type=None, yes=None):
    '''
    Delete a CAA record set and all associated records.
    '''
    return call_az("az network dns record-set caa delete", locals())


def list(resource_group, zone_name, record_type=None):
    '''
    List all CAA record sets in a zone.
    '''
    return call_az("az network dns record-set caa list", locals())


def create(name, resource_group, zone_name, if_match=None, if_none_match=None, metadata=None, record_set_type=None, target_resource=None, ttl=None):
    '''
    Create an empty CAA record set.
    '''
    return call_az("az network dns record-set caa create", locals())


def add_record(flags, record_set_name, resource_group, tag, value, zone_name, if_none_match=None, ttl=None):
    '''
    Add a CAA record.
    '''
    return call_az("az network dns record-set caa add-record", locals())


def remove_record(flags, record_set_name, resource_group, tag, value, zone_name, keep_empty_record_set=None):
    '''
    Remove a CAA record from its record set.
    '''
    return call_az("az network dns record-set caa remove-record", locals())


def update(name, resource_group, zone_name, add=None, force_string=None, if_match=None, if_none_match=None, metadata=None, record_type=None, remove=None, set=None, target_resource=None):
    '''
    Update a CAA record set.
    '''
    return call_az("az network dns record-set caa update", locals())




from .... pyaz_utils import call_az

def create(autoscale_name, condition, scale, cooldown=None, profile_name=None, resource=None, resource_group=None, resource_namespace=None, resource_parent=None, resource_type=None, timegrain=None):
    '''
    Add a new autoscale rule.
    '''
    return call_az("az monitor autoscale rule create", locals())


def list(autoscale_name, resource_group, profile_name=None):
    '''
    List autoscale rules for a profile.
    '''
    return call_az("az monitor autoscale rule list", locals())


def delete(autoscale_name, index, resource_group, profile_name=None):
    '''
    Remove autoscale rules from a profile.
    '''
    return call_az("az monitor autoscale rule delete", locals())


def copy(autoscale_name, dest_schedule, index, resource_group, source_schedule=None):
    '''
    Copy autoscale rules from one profile to another.
    '''
    return call_az("az monitor autoscale rule copy", locals())




from ... pyaz_utils import call_az

def show(name, resource_group=None):
    '''
    Show the container registry's encryption details
    '''
    return call_az("az acr encryption show", locals())


def rotate_key(name, identity=None, key_encryption_key=None, resource_group=None):
    '''
    Rotate (update) the container registry's encryption key
    '''
    return call_az("az acr encryption rotate-key", locals())




from ... pyaz_utils import call_az

def list():
    '''
    List of secure-scores details and state results.
    '''
    return call_az("az security secure-scores list", locals())


def show(name):
    '''
    Shows a secure score details for selected initiative.
    '''
    return call_az("az security secure-scores show", locals())




from .... pyaz_utils import call_az

def renew(account_name, key, key_type=None, resource_group=None):
    '''
    Regenerate one of the access keys or Kerberos keys (if active directory enabled) for a storage account.
    '''
    return call_az("az storage account keys renew", locals())


def list(account_name, expand_key_type=None, resource_group=None):
    '''
    List the access keys or Kerberos keys (if active directory enabled) for a storage account.
    '''
    return call_az("az storage account keys list", locals())




from .... pyaz_utils import call_az

def show(account_name, container_name, if_match=None, resource_group=None):
    return call_az("az storage container immutability-policy show", locals())


def create(account_name, container_name, allow_protected_append_writes=None, allow_protected_append_writes_all=None, if_match=None, period=None, resource_group=None):
    '''
    Create or update an unlocked immutability policy.
    '''
    return call_az("az storage container immutability-policy create", locals())


def delete(account_name, container_name, if_match, resource_group=None):
    return call_az("az storage container immutability-policy delete", locals())


def lock(account_name, container_name, if_match, resource_group=None):
    return call_az("az storage container immutability-policy lock", locals())


def extend(account_name, container_name, if_match, allow_protected_append_writes=None, allow_protected_append_writes_all=None, period=None, resource_group=None):
    '''
    Extend the immutabilityPeriodSinceCreationInDays of a locked immutabilityPolicy.
    '''
    return call_az("az storage container immutability-policy extend", locals())




from ..... pyaz_utils import call_az

def update(group_name, name, resource_group, add=None, force_string=None, remove=None, set=None, sqlvms=None):
    '''
    Updates an availability group listener.
    '''
    return call_az("az sql vm group ag-listener update", locals())


def show(group_name, name, resource_group):
    return call_az("az sql vm group ag-listener show", locals())


def list(group_name, resource_group):
    return call_az("az sql vm group ag-listener list", locals())


def delete(group_name, name, resource_group, yes=None):
    return call_az("az sql vm group ag-listener delete", locals())


def create(ag_name, group_name, ip_address, load_balancer, name, probe_port, resource_group, sqlvms, subnet, port=None, public_ip=None, vnet_name=None):
    '''
    Creates an availability group listener.
    '''
    return call_az("az sql vm group ag-listener create", locals())




from ... pyaz_utils import call_az
from . import auth, gateway, peering, port


def delete(name, resource_group, no_wait=None):
    '''
    Delete an ExpressRoute circuit.
    '''
    return call_az("az network express-route delete", locals())


def show(name, resource_group):
    '''
    Get the details of an ExpressRoute circuit.
    '''
    return call_az("az network express-route show", locals())


def get_stats(name, resource_group):
    '''
    Get the statistics of an ExpressRoute circuit.
    '''
    return call_az("az network express-route get-stats", locals())


def list_arp_tables(name, path, peering_name, resource_group):
    '''
    Show the current Address Resolution Protocol (ARP) table of an ExpressRoute circuit.
    '''
    return call_az("az network express-route list-arp-tables", locals())


def list_route_tables(name, path, peering_name, resource_group):
    '''
    Show the current routing table of an ExpressRoute circuit peering.
    '''
    return call_az("az network express-route list-route-tables", locals())


def list_route_tables_summary(name, path, peering_name, resource_group):
    '''
    Show the current routing table summary of an ExpressRoute circuit peering.
    '''
    return call_az("az network express-route list-route-tables-summary", locals())


def create(bandwidth, name, peering_location, provider, resource_group, allow_classic_operations=None, allow_global_reach=None, express_route_port=None, location=None, no_wait=None, sku_family=None, sku_tier=None, tags=None):
    '''
    Create an ExpressRoute circuit.
    '''
    return call_az("az network express-route create", locals())


def list(resource_group=None):
    '''
    List all ExpressRoute circuits for the current subscription.
    '''
    return call_az("az network express-route list", locals())


def list_service_providers():
    '''
    List available ExpressRoute service providers.
    '''
    return call_az("az network express-route list-service-providers", locals())


def update(name, resource_group, add=None, allow_classic_operations=None, allow_global_reach=None, bandwidth=None, express_route_port=None, force_string=None, no_wait=None, peering_location=None, provider=None, remove=None, set=None, sku_family=None, sku_tier=None, tags=None):
    '''
    Update settings of an ExpressRoute circuit.
    '''
    return call_az("az network express-route update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the ExpressRoute is met.
    '''
    return call_az("az network express-route wait", locals())




from .... pyaz_utils import call_az

def create(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, expiry=None, lease_id=None, permissions=None, sas_token=None, start=None):
    return call_az("az storage container policy create", locals())


def delete(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, lease_id=None, sas_token=None):
    return call_az("az storage container policy delete", locals())


def update(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, expiry=None, lease_id=None, permissions=None, sas_token=None, start=None):
    return call_az("az storage container policy update", locals())


def show(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, lease_id=None, sas_token=None):
    return call_az("az storage container policy show", locals())


def list(container_name, account_key=None, account_name=None, auth_mode=None, connection_string=None, lease_id=None, sas_token=None):
    return call_az("az storage container policy list", locals())




from .... pyaz_utils import call_az

def reset(name, append=None, cert=None, create_cert=None, credential_description=None, end_date=None, keyvault=None, password=None, years=None):
    '''
    Reset a service principal credential.
    '''
    return call_az("az ad sp credential reset", locals())


def list(id, cert=None):
    '''
    List a service principal's credentials.
    '''
    return call_az("az ad sp credential list", locals())


def delete(id, key_id, cert=None):
    '''
    Delete a service principal's credential.
    '''
    return call_az("az ad sp credential delete", locals())




from .... pyaz_utils import call_az

def add(customizer_name, name, resource_group, type, dest_path=None, exit_codes=None, file_source=None, filters=None, inline_script=None, restart_check_command=None, restart_command=None, restart_timeout=None, script_url=None, search_criteria=None, update_limit=None):
    '''
    Add an image builder customizer to an image builder template.
    '''
    return call_az("az image builder customizer add", locals())


def remove(customizer_name, name, resource_group):
    '''
    Remove an image builder customizer from an image builder template.
    '''
    return call_az("az image builder customizer remove", locals())


def clear(name, resource_group):
    '''
    Remove all image builder customizers from an image builder template.
    '''
    return call_az("az image builder customizer clear", locals())




from .... pyaz_utils import call_az

def create(name, remote_vnet, resource_group, vnet_name, allow_forwarded_traffic=None, allow_gateway_transit=None, allow_vnet_access=None, use_remote_gateways=None):
    '''
    Create a virtual network peering connection.
    '''
    return call_az("az network vnet peering create", locals())


def show(name, resource_group, vnet_name):
    '''
    Show details of a peering.
    '''
    return call_az("az network vnet peering show", locals())


def list(resource_group, vnet_name):
    '''
    List peerings.
    '''
    return call_az("az network vnet peering list", locals())


def delete(name, resource_group, vnet_name):
    '''
    Delete a peering.
    '''
    return call_az("az network vnet peering delete", locals())


def update(name, resource_group, vnet_name, add=None, force_string=None, remove=None, set=None):
    '''
    Update a peering.
    '''
    return call_az("az network vnet peering update", locals())




from .... pyaz_utils import call_az

def renew(key, name, resource_group):
    '''
    Regenerate either the primary or secondary key for use with the Maps APIs. The old key will stop working immediately.
    '''
    return call_az("az maps account keys renew", locals())


def list(name, resource_group):
    '''
    Get the keys to use with the Maps APIs. A key is used to authenticate and authorize access to the Maps REST APIs. Only one key is needed at a time; two are given to provide seamless key regeneration.
    '''
    return call_az("az maps account keys list", locals())




from ..... pyaz_utils import call_az

def add(connection_monitor, location, type, workspace_id=None):
    '''
    Add an output to a connection monitor
    '''
    return call_az("az network watcher connection-monitor output add", locals())


def remove(connection_monitor, location):
    '''
    Remove all outputs from a connection monitor
    '''
    return call_az("az network watcher connection-monitor output remove", locals())


def list(connection_monitor, location):
    '''
    List all output from a connection monitor
    '''
    return call_az("az network watcher connection-monitor output list", locals())




from ... pyaz_utils import call_az

def show(name, resource_group):
    '''
    Get the details for an instance pool.
    '''
    return call_az("az sql instance-pool show", locals())


def list(resource_group=None):
    '''
    List available instance pools.
    '''
    return call_az("az sql instance-pool list", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Update an instance pool.
    '''
    return call_az("az sql instance-pool update", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    Delete an instance pool.
    '''
    return call_az("az sql instance-pool delete", locals())


def create(capacity, family, location, name, resource_group, subnet, tier, license_type=None, no_wait=None, tags=None, vnet_name=None):
    '''
    Create an instance pool.
    '''
    return call_az("az sql instance-pool create", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Wait for an instance pool to reach a desired state.
    '''
    return call_az("az sql instance-pool wait", locals())




from .... pyaz_utils import call_az

def add(account_name, name, resource_group):
    '''
    Attach a secondary storage to an Azure Media Services account.
    '''
    return call_az("az ams account storage add", locals())


def remove(account_name, name, resource_group):
    '''
    Detach a secondary storage from an Azure Media Services account.
    '''
    return call_az("az ams account storage remove", locals())


def set_authentication(account_name, resource_group, storage_auth):
    '''
    Set the authentication of a storage account attached to an Azure Media Services account.
    '''
    return call_az("az ams account storage set-authentication", locals())


def sync_storage_keys(account_name, resource_group, storage_account_id):
    '''
    Synchronize storage account keys for a storage account associated with an Azure Media Services account.
    '''
    return call_az("az ams account storage sync-storage-keys", locals())




from ... pyaz_utils import call_az
from . import version


def list(gallery_name, resource_group):
    return call_az("az sig gallery-application list", locals())


def show(gallery_name, name, resource_group):
    return call_az("az sig gallery-application show", locals())


def create(gallery_name, name, os_type, resource_group, description=None, location=None, no_wait=None, tags=None):
    '''
    Create a gallery Application Definition.
    '''
    return call_az("az sig gallery-application create", locals())


def update(gallery_name, name, resource_group, description=None, location=None, no_wait=None, tags=None):
    '''
    Update a gallery Application Definition.
    '''
    return call_az("az sig gallery-application update", locals())


def delete(gallery_name, name, resource_group, no_wait=None, yes=None):
    return call_az("az sig gallery-application delete", locals())


def wait(gallery_name, name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the sig gallery-application is met.
    '''
    return call_az("az sig gallery-application wait", locals())




from .... pyaz_utils import call_az

def list(custom_role_only=None, hsm_name=None, scope=None):
    return call_az("az keyvault role definition list", locals())


def create(hsm_name, role_definition):
    '''
    Create a custom role definition.
    '''
    return call_az("az keyvault role definition create", locals())


def update(hsm_name, role_definition):
    '''
    Update a role definition.
    '''
    return call_az("az keyvault role definition update", locals())


def delete(hsm_name, name=None, role_id=None):
    '''
    Delete a role definition.
    '''
    return call_az("az keyvault role definition delete", locals())


def show(hsm_name, name=None, role_id=None):
    '''
    Show the details of a role definition.
    '''
    return call_az("az keyvault role definition show", locals())




from .... pyaz_utils import call_az

def add(name, resource_group, artifact_tags=None, gallery_image_definition=None, gallery_name=None, gallery_replication_regions=None, is_vhd=None, managed_image=None, managed_image_location=None, output_name=None):
    '''
    Add an image builder output distributor to an image builder template.
    '''
    return call_az("az image builder output add", locals())


def remove(name, output_name, resource_group):
    '''
    Remove an image builder output distributor from an image builder template.
    '''
    return call_az("az image builder output remove", locals())


def clear(name, resource_group):
    '''
    Remove all image builder output distributors from an image builder template.
    '''
    return call_az("az image builder output clear", locals())




from .... pyaz_utils import call_az
from . import action_group, scope


def list(resource_group=None):
    '''
    List activity log alerts under a resource group or the current subscription.
    '''
    return call_az("az monitor activity-log alert list", locals())


def create(name, resource_group, action_group=None, condition=None, description=None, disable=None, scope=None, tags=None, webhook_properties=None):
    '''
    Create a default activity log alert
    '''
    return call_az("az monitor activity-log alert create", locals())


def show(name, resource_group):
    return call_az("az monitor activity-log alert show", locals())


def delete(name, resource_group):
    return call_az("az monitor activity-log alert delete", locals())


def update(name, resource_group, add=None, condition=None, description=None, enabled=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Update the details of this activity log alert
    '''
    return call_az("az monitor activity-log alert update", locals())




from .... pyaz_utils import call_az

def list(kusto_pool_name, resource_group, workspace_name):
    '''
    Lists all Kusto pool principalAssignments.
    '''
    return call_az("az synapse kusto pool-principal-assignment list", locals())


def show(kusto_pool_name, principal_assignment_name, resource_group, workspace_name):
    '''
    Gets a Kusto pool principalAssignment.
    '''
    return call_az("az synapse kusto pool-principal-assignment show", locals())


def create(kusto_pool_name, principal_assignment_name, resource_group, workspace_name, no_wait=None, principal_id=None, principal_type=None, role=None, tenant_id=None):
    '''
    Create a Kusto pool principalAssignment.
    '''
    return call_az("az synapse kusto pool-principal-assignment create", locals())


def update(kusto_pool_name, principal_assignment_name, resource_group, workspace_name, add=None, force_string=None, no_wait=None, principal_id=None, principal_type=None, remove=None, role=None, set=None, tenant_id=None):
    '''
    Update a Kusto pool principalAssignment.
    '''
    return call_az("az synapse kusto pool-principal-assignment update", locals())


def delete(kusto_pool_name, principal_assignment_name, resource_group, workspace_name, no_wait=None, yes=None):
    '''
    Deletes a Kusto pool principalAssignment.
    '''
    return call_az("az synapse kusto pool-principal-assignment delete", locals())


def wait(kusto_pool_name, principal_assignment_name, resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the synapse kusto pool-principal-assignment is met.
    '''
    return call_az("az synapse kusto pool-principal-assignment wait", locals())




from ..... pyaz_utils import call_az

def create(account_name, principal_id, resource_group, scope, no_wait=None, role_assignment_id=None, role_definition_id=None, role_definition_name=None):
    '''
    Create a SQL role assignment under an Azure Cosmos DB account.
    '''
    return call_az("az cosmosdb sql role assignment create", locals())


def update(account_name, resource_group, role_assignment_id, no_wait=None, principal_id=None, role_definition_id=None, role_definition_name=None, scope=None):
    '''
    Update a SQL role assignment under an Azure Cosmos DB account.
    '''
    return call_az("az cosmosdb sql role assignment update", locals())


def exists(account_name, resource_group, role_assignment_id):
    '''
    Check if an Azure Cosmos DB role assignment exists.
    '''
    return call_az("az cosmosdb sql role assignment exists", locals())


def list(account_name, resource_group):
    '''
    List all SQL role assignments under an Azure Cosmos DB account.
    '''
    return call_az("az cosmosdb sql role assignment list", locals())


def show(account_name, resource_group, role_assignment_id):
    '''
    Show the properties of a SQL role assignment under an Azure Cosmos DB account.
    '''
    return call_az("az cosmosdb sql role assignment show", locals())


def delete(account_name, resource_group, role_assignment_id, no_wait=None, yes=None):
    '''
    Delete a SQL role assignment under an Azure Cosmos DB account.
    '''
    return call_az("az cosmosdb sql role assignment delete", locals())


def wait(account_name, resource_group, role_assignment_id, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Poll on a SQL role assignment until a specific condition is met.
    '''
    return call_az("az cosmosdb sql role assignment wait", locals())




from .... pyaz_utils import call_az

def show(name, resource_group, workspace_name):
    '''
    Get a Spark pool.
    '''
    return call_az("az synapse spark pool show", locals())


def list(resource_group, workspace_name):
    '''
    List all Spark pools.
    '''
    return call_az("az synapse spark pool list", locals())


def create(name, node_count, node_size, resource_group, spark_version, workspace_name, delay=None, enable_auto_pause=None, enable_auto_scale=None, max_node_count=None, min_node_count=None, no_wait=None, node_size_family=None, spark_config_file_path=None, spark_events_folder=None, spark_log_folder=None, tags=None):
    '''
    Create a Spark pool.
    '''
    return call_az("az synapse spark pool create", locals())


def update(name, resource_group, workspace_name, delay=None, enable_auto_pause=None, enable_auto_scale=None, force=None, library_requirements=None, max_node_count=None, min_node_count=None, no_wait=None, node_count=None, node_size=None, package=None, package_action=None, spark_config_file_path=None, tags=None):
    '''
    Update the Spark pool.
    '''
    return call_az("az synapse spark pool update", locals())


def delete(name, resource_group, workspace_name, no_wait=None, yes=None):
    '''
    Delete a Spark pool.
    '''
    return call_az("az synapse spark pool delete", locals())


def wait(big_data_pool_name, resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a Spark pool is met.
    '''
    return call_az("az synapse spark pool wait", locals())




from ... pyaz_utils import call_az

def create(name, resource_group, location=None, tags=None, vnets=None):
    '''
    Create a DDoS protection plan.
    '''
    return call_az("az network ddos-protection create", locals())


def delete(name, resource_group):
    '''
    Delete a DDoS protection plan.
    '''
    return call_az("az network ddos-protection delete", locals())


def list(resource_group=None):
    '''
    List DDoS protection plans.
    '''
    return call_az("az network ddos-protection list", locals())


def show(name, resource_group):
    '''
    Show details of a DDoS protection plan.
    '''
    return call_az("az network ddos-protection show", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None, tags=None, vnets=None):
    '''
    Update a DDoS protection plan.
    '''
    return call_az("az network ddos-protection update", locals())




from ... pyaz_utils import call_az

def browse(name, resource_group, disable_browser=None, ssh_key_file=None):
    return call_az("az acs kubernetes browse", locals())


def get_credentials(name, resource_group, file=None, overwrite_existing=None, ssh_key_file=None):
    '''
    Download and install credentials to access a cluster.  This command requires the same private-key used to create the cluster.
    '''
    return call_az("az acs kubernetes get-credentials", locals())


def install_cli(base_src_url=None, client_version=None, install_location=None, kubelogin_base_src_url=None, kubelogin_install_location=None, kubelogin_version=None):
    '''
    Download and install the Kubernetes command-line tool for a cluster.
    '''
    return call_az("az acs kubernetes install-cli", locals())




from ..... pyaz_utils import call_az

def list(resource_group, workspace_name):
    '''
    List all data export ruleses for a given workspace.
    '''
    return call_az("az monitor log-analytics workspace data-export list", locals())


def show(name, resource_group, workspace_name):
    '''
    Show a data export rule for a given workspace.
    '''
    return call_az("az monitor log-analytics workspace data-export show", locals())


def create(destination, name, resource_group, tables, workspace_name, enable=None):
    '''
    Create a data export rule for a given workspace.
    '''
    return call_az("az monitor log-analytics workspace data-export create", locals())


def update(name, resource_group, tables, workspace_name, add=None, destination=None, enable=None, force_string=None, remove=None, set=None):
    '''
    Update a data export rule for a given workspace.
    '''
    return call_az("az monitor log-analytics workspace data-export update", locals())


def delete(name, resource_group, workspace_name, yes=None):
    '''
    Delete a data export rule for a given workspace.
    '''
    return call_az("az monitor log-analytics workspace data-export delete", locals())




from ... pyaz_utils import call_az
from . import db, deploy, firewall_rule, migration, parameter


def create(address_prefixes=None, admin_password=None, admin_user=None, backup_retention=None, database_name=None, high_availability=None, location=None, name=None, private_dns_zone=None, public_access=None, resource_group=None, sku_name=None, standby_zone=None, storage_size=None, subnet=None, subnet_prefixes=None, tags=None, tier=None, version=None, vnet=None, yes=None, zone=None):
    '''
    Create a PostgreSQL flexible server.
    '''
    return call_az("az postgres flexible-server create", locals())


def restore(name, resource_group, source_server, address_prefixes=None, no_wait=None, private_dns_zone=None, restore_time=None, subnet=None, subnet_prefixes=None, vnet=None, yes=None, zone=None):
    '''
    Restore a flexible server from backup.
    '''
    return call_az("az postgres flexible-server restore", locals())


def start(name, resource_group):
    '''
    Start a flexible server.
    '''
    return call_az("az postgres flexible-server start", locals())


def stop(name=None, resource_group=None):
    '''
    Stop a flexible server.
    '''
    return call_az("az postgres flexible-server stop", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete a flexible server.
    '''
    return call_az("az postgres flexible-server delete", locals())


def show(name, resource_group):
    '''
    Get the details of a flexible server.
    '''
    return call_az("az postgres flexible-server show", locals())


def list(resource_group=None):
    '''
    List available flexible servers.
    '''
    return call_az("az postgres flexible-server list", locals())


def update(name, resource_group, add=None, admin_password=None, backup_retention=None, force_string=None, high_availability=None, maintenance_window=None, remove=None, set=None, sku_name=None, standby_zone=None, storage_size=None, tags=None, tier=None):
    '''
    Update a flexible server.
    '''
    return call_az("az postgres flexible-server update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Wait for the flexible server to satisfy certain conditions.
    '''
    return call_az("az postgres flexible-server wait", locals())


def restart(name, resource_group, failover=None):
    '''
    Restart a flexible server.
    '''
    return call_az("az postgres flexible-server restart", locals())


def list_skus(location):
    '''
    Lists available sku's in the given region.
    '''
    return call_az("az postgres flexible-server list-skus", locals())


def show_connection_string(admin_password=None, admin_user=None, database_name=None, server_name=None):
    '''
    Show the connection strings for a PostgreSQL flexible-server database.
    '''
    return call_az("az postgres flexible-server show-connection-string", locals())




from .... pyaz_utils import call_az

def add(cluster_name, node_type, number_of_nodes_to_add, resource_group):
    '''
    Add nodes to a node type in a cluster.
    '''
    return call_az("az sf cluster node add", locals())


def remove(cluster_name, node_type, number_of_nodes_to_remove, resource_group):
    '''
    Remove nodes from a node type in a cluster.
    '''
    return call_az("az sf cluster node remove", locals())




from ... pyaz_utils import call_az

def create(condition, name, target, action=None, description=None, disabled=None, email_service_owners=None, location=None, resource_group=None, tags=None, target_namespace=None, target_parent=None, target_type=None):
    '''
    Create a classic metric-based alert rule.
    '''
    return call_az("az monitor alert create", locals())


def delete(name, resource_group):
    '''
    Delete an alert rule.
    '''
    return call_az("az monitor alert delete", locals())


def show(name, resource_group):
    '''
    Show an alert rule.
    '''
    return call_az("az monitor alert show", locals())


def list(resource_group):
    '''
    List alert rules in a resource group.
    '''
    return call_az("az monitor alert list", locals())


def show_incident(name, resource_group, rule_name):
    '''
    Get the details of an alert rule incident.
    '''
    return call_az("az monitor alert show-incident", locals())


def list_incidents(resource_group, rule_name):
    '''
    List all incidents for an alert rule.
    '''
    return call_az("az monitor alert list-incidents", locals())


def update(name, add=None, add_action=None, aggregation=None, condition=None, description=None, email_service_owners=None, enabled=None, force_string=None, metric=None, operator=None, period=None, remove=None, remove_action=None, resource=None, resource_group=None, resource_namespace=None, resource_parent=None, resource_type=None, set=None, tags=None, threshold=None):
    '''
    Update a classic metric-based alert rule.
    '''
    return call_az("az monitor alert update", locals())




from ... pyaz_utils import call_az

def assign(name, resource_group, identities=None, role=None, scope=None):
    '''
    Enable managed service identity on a VMSS.
    '''
    return call_az("az vmss identity assign", locals())


def remove(name, resource_group, identities=None):
    '''
    Remove user assigned identities from a VM scaleset.
    '''
    return call_az("az vmss identity remove", locals())


def show(name, resource_group):
    '''
    display VM scaleset's managed identity info.
    '''
    return call_az("az vmss identity show", locals())




from .... pyaz_utils import call_az

def show(account, data_lake_store_account_name, resource_group=None):
    return call_az("az dla account data-lake-store show", locals())


def list(account, count=None, filter=None, orderby=None, resource_group=None, select=None, skip=None, top=None):
    return call_az("az dla account data-lake-store list", locals())


def add(account, data_lake_store_account_name, resource_group=None, suffix=None):
    return call_az("az dla account data-lake-store add", locals())


def delete(account, data_lake_store_account_name, resource_group=None):
    return call_az("az dla account data-lake-store delete", locals())




from ... pyaz_utils import call_az
from . import metadata


def create(name, share_name, account_key=None, account_name=None, connection_string=None, fail_on_exist=None, metadata=None, sas_token=None, timeout=None):
    return call_az("az storage directory create", locals())


def delete(name, share_name, account_key=None, account_name=None, connection_string=None, fail_not_exist=None, sas_token=None, timeout=None):
    return call_az("az storage directory delete", locals())


def show(name, share_name, account_key=None, account_name=None, connection_string=None, sas_token=None, snapshot=None, timeout=None):
    return call_az("az storage directory show", locals())


def exists(name, share_name, account_key=None, account_name=None, connection_string=None, sas_token=None, snapshot=None, timeout=None):
    '''
    Check for the existence of a storage directory.
    '''
    return call_az("az storage directory exists", locals())


def list(share_name, account_key=None, account_name=None, connection_string=None, name=None, sas_token=None, timeout=None):
    '''
    List directories in a share.
    '''
    return call_az("az storage directory list", locals())




from ... pyaz_utils import call_az

def show(name, resource_group, server):
    return call_az("az sql failover-group show", locals())


def list(resource_group, server):
    return call_az("az sql failover-group list", locals())


def create(name, partner_server, resource_group, server, add_db=None, failover_policy=None, grace_period=None, partner_resource_group=None):
    '''
    Creates a failover group.
    '''
    return call_az("az sql failover-group create", locals())


def update(name, resource_group, server, add=None, add_db=None, failover_policy=None, force_string=None, grace_period=None, remove=None, remove_db=None, set=None):
    '''
    Updates the failover group.
    '''
    return call_az("az sql failover-group update", locals())


def delete(name, resource_group, server):
    return call_az("az sql failover-group delete", locals())


def set_primary(name, resource_group, server, allow_data_loss=None):
    '''
    Set the primary of the failover group by failing over all databases from the current primary server.
    '''
    return call_az("az sql failover-group set-primary", locals())




from ... pyaz_utils import call_az
from . import dns_zone_group


def create(connection_name, name, private_connection_resource_id, resource_group, subnet, edge_zone=None, group_id=None, location=None, manual_request=None, request_message=None, tags=None, vnet_name=None):
    '''
    Create a private endpoint.
    '''
    return call_az("az network private-endpoint create", locals())


def delete(name, resource_group):
    '''
    Delete a private endpoint.
    '''
    return call_az("az network private-endpoint delete", locals())


def list(resource_group=None):
    '''
    List private endpoints.
    '''
    return call_az("az network private-endpoint list", locals())


def show(name, resource_group):
    '''
    Get the details of a private endpoint.
    '''
    return call_az("az network private-endpoint show", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, request_message=None, set=None, tags=None):
    '''
    Update a private endpoint.
    '''
    return call_az("az network private-endpoint update", locals())


def list_types(location):
    return call_az("az network private-endpoint list-types", locals())




from .... pyaz_utils import call_az

def create(account_name, name, sas_type, template_uri, validity_period, vault_name, disabled=None, tags=None):
    return call_az("az keyvault storage sas-definition create", locals())


def list(account_name, vault_name, maxresults=None):
    return call_az("az keyvault storage sas-definition list", locals())


def show(account_name=None, id=None, name=None, vault_name=None):
    return call_az("az keyvault storage sas-definition show", locals())


def update(account_name=None, disabled=None, id=None, name=None, sas_type=None, tags=None, template_uri=None, validity_period=None, vault_name=None):
    return call_az("az keyvault storage sas-definition update", locals())


def delete(account_name=None, id=None, name=None, vault_name=None):
    return call_az("az keyvault storage sas-definition delete", locals())


def list_deleted(account_name, vault_name, maxresults=None):
    return call_az("az keyvault storage sas-definition list-deleted", locals())


def show_deleted(account_name, name, vault_name):
    return call_az("az keyvault storage sas-definition show-deleted", locals())


def recover(account_name, name, vault_name):
    return call_az("az keyvault storage sas-definition recover", locals())




from ... pyaz_utils import call_az

def create(account_name, name, resource_group, bitrate=None, end_timestamp=None, first_quality=None, force_end_timestamp=None, live_backoff_duration=None, presentation_window_duration=None, start_timestamp=None, timescale=None, tracks=None):
    '''
    Create an account filter.
    '''
    return call_az("az ams account-filter create", locals())


def show(account_name, name, resource_group):
    '''
    Show the details of an account filter.
    '''
    return call_az("az ams account-filter show", locals())


def list(account_name, resource_group):
    '''
    List all the account filters of an Azure Media Services account.
    '''
    return call_az("az ams account-filter list", locals())


def delete(account_name, name, resource_group):
    '''
    Delete an account filter.
    '''
    return call_az("az ams account-filter delete", locals())


def update(account_name, name, resource_group, add=None, bitrate=None, end_timestamp=None, first_quality=None, force_end_timestamp=None, force_string=None, live_backoff_duration=None, presentation_window_duration=None, remove=None, set=None, start_timestamp=None, timescale=None, tracks=None):
    '''
    Update the details of an account filter.
    '''
    return call_az("az ams account-filter update", locals())




from ... pyaz_utils import call_az

def attach(resource_group, vm_name, caching=None, lun=None, name=None, new=None, size_gb=None, vhd_uri=None):
    '''
    Attach an unmanaged persistent disk to a VM.
    '''
    return call_az("az vm unmanaged-disk attach", locals())


def detach(name, resource_group, vm_name):
    '''
    Detach an unmanaged disk from a VM.
    '''
    return call_az("az vm unmanaged-disk detach", locals())


def list(resource_group, vm_name):
    '''
    List unmanaged disks of a VM.
    '''
    return call_az("az vm unmanaged-disk list", locals())




from .... pyaz_utils import call_az

def add(namespace_name, resource_group, action=None, ignore_missing_endpoint=None, ip_address=None, subnet=None, vnet_name=None):
    '''
    Add a network rule for a namespace.
    '''
    return call_az("az eventhubs namespace network-rule add", locals())


def list(namespace_name, resource_group):
    '''
    Show properties of Network rule of the given Namespace.
    '''
    return call_az("az eventhubs namespace network-rule list", locals())


def remove(namespace_name, resource_group, ip_address=None, subnet=None, vnet_name=None):
    '''
    Remove network rule for a namespace
    '''
    return call_az("az eventhubs namespace network-rule remove", locals())




from .. pyaz_utils import call_az
from . import alert, bandwidth_schedule, device, order


def show_job(device_name, name, resource_group):
    '''
    Get the details of a specified job on a Data Box Edge/Data Box Gateway device.
    '''
    return call_az("az databoxedge show-job", locals())


def list_node(device_name, resource_group):
    '''
    Get all the nodes currently configured under this Data Box Edge device.
    '''
    return call_az("az databoxedge list-node", locals())


def list_sku(filter=None):
    '''
    List all the available Skus in the region and information related to them.
    '''
    return call_az("az databoxedge list-sku", locals())




from ... pyaz_utils import call_az
from . import authorization_rule, subscription


def create(name, namespace_name, resource_group, auto_delete_on_idle=None, default_message_time_to_live=None, duplicate_detection_history_time_window=None, enable_batched_operations=None, enable_duplicate_detection=None, enable_express=None, enable_ordering=None, enable_partitioning=None, max_size=None, status=None):
    '''
    Create the Service Bus Topic
    '''
    return call_az("az servicebus topic create", locals())


def show(name, namespace_name, resource_group):
    '''
    Shows the Service Bus Topic Details
    '''
    return call_az("az servicebus topic show", locals())


def list(namespace_name, resource_group, skip=None, top=None):
    '''
    List the Topic by Service Bus Namespace
    '''
    return call_az("az servicebus topic list", locals())


def delete(name, namespace_name, resource_group):
    '''
    Deletes the Service Bus Topic
    '''
    return call_az("az servicebus topic delete", locals())


def update(name, namespace_name, resource_group, add=None, auto_delete_on_idle=None, default_message_time_to_live=None, duplicate_detection_history_time_window=None, enable_batched_operations=None, enable_duplicate_detection=None, enable_express=None, enable_ordering=None, enable_partitioning=None, force_string=None, max_size=None, remove=None, set=None, status=None):
    '''
    Updates the Service Bus Topic
    '''
    return call_az("az servicebus topic update", locals())




from ... pyaz_utils import call_az
from . import version


def list(cluster_name, resource_group):
    '''
    List application types of a given cluster.
    '''
    return call_az("az sf application-type list", locals())


def delete(cluster_name, name, resource_group):
    '''
    Delete an application type.
    '''
    return call_az("az sf application-type delete", locals())


def show(cluster_name, name, resource_group):
    '''
    Show the properties of an application type on an Azure Service Fabric cluster.
    '''
    return call_az("az sf application-type show", locals())


def create(cluster_name, name, resource_group):
    '''
    Create a new application type on an Azure Service Fabric cluster.
    '''
    return call_az("az sf application-type create", locals())




from .... pyaz_utils import call_az

def show(account_name, backup_name, resource_group):
    '''
    Get Backup for a Netapp Files (ANF) Account.
    '''
    return call_az("az netappfiles account backup show", locals())


def list(account_name, resource_group):
    '''
    Get list of all Azure NetApp Files (ANF) Account Backups.
    '''
    return call_az("az netappfiles account backup list", locals())


def delete(account_name, backup_name, resource_group, yes=None):
    '''
    Delete Backup for a Netapp Files (ANF) Account.
    '''
    return call_az("az netappfiles account backup delete", locals())




from ... pyaz_utils import call_az

def list(resource_group=None):
    '''
    List app service environments.
    '''
    return call_az("az appservice ase list", locals())


def list_addresses(name, resource_group=None):
    '''
    List VIPs associated with an app service environment v2.
    '''
    return call_az("az appservice ase list-addresses", locals())


def list_plans(name, resource_group=None):
    '''
    List app service plans associated with an app service environment.
    '''
    return call_az("az appservice ase list-plans", locals())


def show(name, resource_group=None):
    '''
    Show details of an app service environment.
    '''
    return call_az("az appservice ase show", locals())


def create(name, resource_group, subnet, force_network_security_group=None, force_route_table=None, front_end_scale_factor=None, front_end_sku=None, ignore_network_security_group=None, ignore_route_table=None, ignore_subnet_size_validation=None, kind=None, location=None, no_wait=None, os_preference=None, virtual_ip_type=None, vnet_name=None, zone_redundant=None):
    '''
    Create app service environment.
    '''
    return call_az("az appservice ase create", locals())


def update(name, allow_new_private_endpoint_connections=None, front_end_scale_factor=None, front_end_sku=None, no_wait=None, resource_group=None):
    '''
    Update app service environment.
    '''
    return call_az("az appservice ase update", locals())


def delete(name, no_wait=None, resource_group=None, yes=None):
    '''
    Delete app service environment.
    '''
    return call_az("az appservice ase delete", locals())


def create_inbound_services(name, resource_group, subnet, skip_dns=None, vnet_name=None):
    '''
    Private DNS Zone for Internal ASEv2.
    '''
    return call_az("az appservice ase create-inbound-services", locals())




from ..... pyaz_utils import call_az

def list(resource_group, workspace_name):
    '''
    List all the tables for the given Log Analytics workspace.
    '''
    return call_az("az monitor log-analytics workspace table list", locals())


def show(name, resource_group, workspace_name):
    '''
    Get a Log Analytics workspace table.
    '''
    return call_az("az monitor log-analytics workspace table show", locals())


def update(name, resource_group, retention_time, workspace_name):
    '''
    Update the properties of a Log Analytics workspace table, currently only support updating retention time.
    '''
    return call_az("az monitor log-analytics workspace table update", locals())




from .... pyaz_utils import call_az

def list(lb_name, resource_group):
    '''
    List load balancing rules.
    '''
    return call_az("az network lb rule list", locals())


def show(lb_name, name, resource_group):
    '''
    Get the details of a load balancing rule.
    '''
    return call_az("az network lb rule show", locals())


def delete(lb_name, name, resource_group):
    '''
    Delete a load balancing rule.
    '''
    return call_az("az network lb rule delete", locals())


def create(backend_port, frontend_port, lb_name, name, protocol, resource_group, backend_pool_name=None, backend_pools_name=None, disable_outbound_snat=None, enable_tcp_reset=None, floating_ip=None, frontend_ip_name=None, idle_timeout=None, load_distribution=None, probe_name=None):
    '''
    Create a load balancing rule.
    '''
    return call_az("az network lb rule create", locals())


def update(lb_name, name, resource_group, add=None, backend_pool_name=None, backend_pools_name=None, backend_port=None, disable_outbound_snat=None, enable_tcp_reset=None, floating_ip=None, force_string=None, frontend_ip_name=None, frontend_port=None, idle_timeout=None, load_distribution=None, probe_name=None, protocol=None, remove=None, set=None):
    '''
    Update a load balancing rule.
    '''
    return call_az("az network lb rule update", locals())




from ... pyaz_utils import call_az

def set(lab_name, name, resource_group, value):
    '''
    Set a secret for a lab.
    '''
    return call_az("az lab secret set", locals())


def show(lab_name, name, resource_group, expand=None):
    return call_az("az lab secret show", locals())


def list(lab_name, resource_group, expand=None, filter=None, orderby=None, top=None):
    return call_az("az lab secret list", locals())


def delete(lab_name, name, resource_group):
    return call_az("az lab secret delete", locals())




from ... pyaz_utils import call_az

def check_vm(resource_group=None, vm=None, vm_id=None):
    '''
    Find out whether the virtual machine is protected or not. If protected, it returns the recovery services vault ID, otherwise it returns empty.
    '''
    return call_az("az backup protection check-vm", locals())


def enable_for_vm(policy_name, resource_group, vault_name, vm, disk_list_setting=None, diskslist=None, exclude_all_data_disks=None):
    '''
    Start protecting a previously unprotected Azure VM as per the specified policy to a Recovery services vault.
    '''
    return call_az("az backup protection enable-for-vm", locals())


def update_for_vm(container_name, item_name, resource_group, vault_name, disk_list_setting=None, diskslist=None, exclude_all_data_disks=None):
    '''
    Update disk exclusion settings associated with a backed up VM item.
    '''
    return call_az("az backup protection update-for-vm", locals())


def backup_now(item_name, resource_group, vault_name, backup_management_type=None, backup_type=None, container_name=None, enable_compression=None, retain_until=None, workload_type=None):
    '''
    Perform an on-demand backup of a backed up item.
    '''
    return call_az("az backup protection backup-now", locals())


def disable(container_name, item_name, resource_group, vault_name, backup_management_type=None, delete_backup_data=None, workload_type=None, yes=None):
    '''
    Stop protecting a backed up item. Can retain the backed up data forever or choose to delete it.
    '''
    return call_az("az backup protection disable", locals())


def enable_for_azurefileshare(azure_file_share, policy_name, resource_group, storage_account, vault_name):
    '''
    Start protecting a previously unprotected Azure File share within an Azure Storage account as per the specified policy to a Recovery services vault.
    '''
    return call_az("az backup protection enable-for-azurefileshare", locals())


def enable_for_azurewl(policy_name, protectable_item_name, protectable_item_type, resource_group, server_name, vault_name, workload_type):
    '''
    Start protecting a previously unprotected workload within an Azure VM as per the specified policy to a Recovery services vault. Provide the workload details as a protectable item.
    '''
    return call_az("az backup protection enable-for-azurewl", locals())


def auto_enable_for_azurewl(policy_name, protectable_item_name, protectable_item_type, resource_group, server_name, vault_name, workload_type):
    '''
    Automatically protect all existing unprotected DBs and any DB which will be added later with the given policy.
    '''
    return call_az("az backup protection auto-enable-for-azurewl", locals())


def auto_disable_for_azurewl(protectable_item_name, protectable_item_type, resource_group, server_name, vault_name, workload_type):
    '''
    Disable auto-protection for the specified protectable item.
    '''
    return call_az("az backup protection auto-disable-for-azurewl", locals())


def resume(container_name, item_name, policy_name, resource_group, vault_name, backup_management_type=None, workload_type=None):
    '''
    Resume backup for the associated backup item. Use this to change the policy associated with the backup item.
    '''
    return call_az("az backup protection resume", locals())


def undelete(container_name, item_name, resource_group, vault_name, backup_management_type=None, workload_type=None):
    '''
    Rehydrate an item from softdeleted state to stop protection with retained data state.
    '''
    return call_az("az backup protection undelete", locals())




from ... pyaz_utils import call_az

def show(profile_name, resource_group, rule_set_name):
    return call_az("az afd rule-set show", locals())


def list(profile_name, resource_group):
    return call_az("az afd rule-set list", locals())


def create(profile_name, resource_group, rule_set_name):
    '''
    Creates a new rule set under the specified profile.
    '''
    return call_az("az afd rule-set create", locals())


def delete(profile_name, resource_group, rule_set_name, yes=None):
    '''
    Delete the rule set.
    '''
    return call_az("az afd rule-set delete", locals())




from .... pyaz_utils import call_az

def list(name, resource_group):
    '''
    List all deployment slots.
    '''
    return call_az("az functionapp deployment slot list", locals())


def delete(name, resource_group, slot):
    '''
    Delete a deployment slot.
    '''
    return call_az("az functionapp deployment slot delete", locals())


def auto_swap(name, resource_group, slot, auto_swap_slot=None, disable=None):
    '''
    Configure deployment slot auto swap.
    '''
    return call_az("az functionapp deployment slot auto-swap", locals())


def swap(name, resource_group, slot, action=None, preserve_vnet=None, target_slot=None):
    '''
    Swap deployment slots for a function app.
    '''
    return call_az("az functionapp deployment slot swap", locals())


def create(name, resource_group, slot, configuration_source=None):
    '''
    Create a deployment slot.
    '''
    return call_az("az functionapp deployment slot create", locals())




from .... pyaz_utils import call_az

def create(name, share_name, account_key=None, account_name=None, connection_string=None, expiry=None, permissions=None, sas_token=None, start=None):
    return call_az("az storage share policy create", locals())


def delete(name, share_name, account_key=None, account_name=None, connection_string=None, sas_token=None):
    return call_az("az storage share policy delete", locals())


def show(name, share_name, account_key=None, account_name=None, connection_string=None, sas_token=None):
    return call_az("az storage share policy show", locals())


def list(share_name, account_key=None, account_name=None, connection_string=None, sas_token=None):
    return call_az("az storage share policy list", locals())


def update(name, share_name, account_key=None, account_name=None, connection_string=None, expiry=None, permissions=None, sas_token=None, start=None):
    return call_az("az storage share policy update", locals())




from .... pyaz_utils import call_az

def create(resource_group, server_name, display_name=None, object_id=None):
    '''
    Create a new server Active Directory administrator.
    '''
    return call_az("az sql server ad-admin create", locals())


def list(resource_group, server_name):
    return call_az("az sql server ad-admin list", locals())


def delete(resource_group, server_name):
    return call_az("az sql server ad-admin delete", locals())


def update(resource_group, server_name, add=None, display_name=None, force_string=None, object_id=None, remove=None, set=None):
    '''
    Update an existing server Active Directory administrator.
    '''
    return call_az("az sql server ad-admin update", locals())




from ... pyaz_utils import call_az

def create(cluster_name, data_center_location, data_center_name, delegated_subnet_id, node_count, resource_group, availability_zone=None, backup_storage_customer_key_uri=None, base64_encoded_cassandra_yaml_fragment=None, disk_capacity=None, disk_sku=None, managed_disk_customer_key_uri=None, no_wait=None, sku=None):
    '''
    Create a Datacenter in an Azure Managed Cassandra Cluster.
    '''
    return call_az("az managed-cassandra datacenter create", locals())


def update(cluster_name, data_center_name, resource_group, backup_storage_customer_key_uri=None, base64_encoded_cassandra_yaml_fragment=None, managed_disk_customer_key_uri=None, no_wait=None, node_count=None):
    '''
    Update a Datacenter in an Azure Managed Cassandra Cluster.
    '''
    return call_az("az managed-cassandra datacenter update", locals())


def list(cluster_name, resource_group):
    '''
    List the Managed Cassandra Datacenters in a given Cluster.
    '''
    return call_az("az managed-cassandra datacenter list", locals())


def show(cluster_name, data_center_name, resource_group):
    '''
    Get a Managed Cassandra DataCenter Resource.
    '''
    return call_az("az managed-cassandra datacenter show", locals())


def delete(cluster_name, data_center_name, resource_group, no_wait=None, yes=None):
    '''
    Deletes a Managed Cassandra Datacenter.
    '''
    return call_az("az managed-cassandra datacenter delete", locals())




from ... pyaz_utils import call_az

def list(hsm_name=None, resource_group=None, vault_name=None):
    '''
    List the private link resources supported for a Key Vault/HSM.
    '''
    return call_az("az keyvault private-link-resource list", locals())




from ... pyaz_utils import call_az

def update(retention, services, account_key=None, account_name=None, api=None, connection_string=None, hour=None, minute=None, sas_token=None, timeout=None):
    '''
    Update metrics settings for a storage account.
    '''
    return call_az("az storage metrics update", locals())


def show(account_key=None, account_name=None, connection_string=None, interval=None, sas_token=None, services=None, timeout=None):
    '''
    Show metrics settings for a storage account.
    '''
    return call_az("az storage metrics show", locals())




from .... pyaz_utils import call_az

def create(name, peer_asn, peer_ip, resource_group, vrouter_name):
    '''
    Create a virtual router peering.
    '''
    return call_az("az network vrouter peering create", locals())


def update(name, resource_group, vrouter_name, add=None, force_string=None, peer_asn=None, peer_ip=None, remove=None, set=None):
    '''
    Update a virtual router peering.
    '''
    return call_az("az network vrouter peering update", locals())


def delete(name, resource_group, vrouter_name):
    '''
    Delete a virtual router peering.
    '''
    return call_az("az network vrouter peering delete", locals())


def show(name, resource_group, vrouter_name):
    '''
    Show a virtual router peering
    '''
    return call_az("az network vrouter peering show", locals())


def list(resource_group, vrouter_name):
    '''
    List all virtual router peerings under a resource group.
    '''
    return call_az("az network vrouter peering list", locals())

